@@ -36,6 +36,7 @@ $tablerelgruppi = $PHPR_TAB_PRE."relgruppi";
 $tableanni = $PHPR_TAB_PRE."anni";
 $tableclienti = $PHPR_TAB_PRE."clienti";
 $tabletransazioniweb = $PHPR_TAB_PRE."transazioniweb";
+$tabletransazioni = $PHPR_TAB_PRE."transazioni";
 $tablecontratti = $PHPR_TAB_PRE."contratti";
 $tablerelclienti = $PHPR_TAB_PRE."relclienti";
 $tableappartamenti = $PHPR_TAB_PRE."appartamenti";
@@ -46,11 +47,13 @@ $tableregioni = $PHPR_TAB_PRE."regioni";
 $tablecitta = $PHPR_TAB_PRE."citta";
 $tabledocumentiid = $PHPR_TAB_PRE."documentiid";
 $tableparentele = $PHPR_TAB_PRE."parentele";
+$tablecache = $PHPR_TAB_PRE."cache";
 
 
 
 
 
+# API Documenti
 if ($doc) {
 $session_data = "";
 $id_sessione = "";
@@ -75,10 +78,25 @@ $id_utente = $id_utente[0];
 $pass_api = substr($pass_api,(strlen($id_utente) + 1));
 if ($pass == $pass_api) {
 
-if ($priv_vedi_tab_prenotazioni == "n" and ($priv_vedi_tab_mesi == "n" or $priv_mod_prenotazioni == "n")) {
-$res_year = "";
+$raggiunto_limite = 0;
+if (defined('C_LIMITE_CHIAMATE_API_AL_MINUTO') and C_LIMITE_CHIAMATE_API_AL_MINUTO > 0) {
+$tabelle_lock = array($tablecache);
+$tabelle_lock = lock_tabelle($tabelle_lock);
+$adesso = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
+$minuto = substr($adesso,0,16);
+esegui_query("delete from $tablecache where tipo = 'lim_api' and datainserimento < '$minuto:00' ");
+$lim_api = esegui_query("select * from $tablecache where tipo = 'lim_api' and datainserimento >= '$minuto:00' ");
+if (!numlin_query($lim_api)) esegui_query("insert into $tablecache (numero,tipo,data_modifica,datainserimento) values ('1','lim_api','$adesso','$adesso') ");
+else {
+$num_lim_api = risul_query($lim_api,0,'numero');
+if ($num_lim_api >= C_LIMITE_CHIAMATE_API_AL_MINUTO) $raggiunto_limite = 1;
+else esegui_query("update $tablecache set numero = '".($num_lim_api + 1)."', data_modifica = '$adesso' where tipo = 'lim_api' and datainserimento >= '$minuto:00' ");
+} # fine else if (!numlin_query($lim_api))
+unlock_tabelle($tabelle_lock);
+} # fine if (defined('C_LIMITE_CHIAMATE_API_AL_MINUTO') and C_LIMITE_CHIAMATE_API_AL_MINUTO > 0)
+if ($raggiunto_limite) echo "REACHED LIMIT IN LAST MINUTE (".C_LIMITE_CHIAMATE_API_AL_MINUTO.").\n";
+else {
 
-} # fine if ($priv_vedi_tab_prenotazioni == "n" and ($priv_vedi_tab_mesi == "n" or $priv_mod_prenotazioni == "n"))
 
 if ($res_year) {
 if (preg_match("/[0-9]{4,4}/",$res_year)) {
@@ -169,7 +187,7 @@ $nome_contratto = $nomi_contratti['salv'][$numero_contratto];
 $cont_salva = "SI";
 $sovrascrivi = "";
 
-define(C_ID_UTENTE,$id_utente);
+define('C_ID_UTENTE',$id_utente);
 $campi_pers_comm = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'campi_pers_comm' and idutente = '$id_utente'");
 if (numlin_query($campi_pers_comm) == 1) {
 $campi_pers_comm = explode(">",risul_query($campi_pers_comm,0,'valpersonalizza'));
@@ -337,7 +355,7 @@ $query_prenota = "select idprenota from $tableprenota where iddatafine >= '$prim
 if ($query_prenota or $query_clienti) {
 $num_ripeti = 0;
 
-if ($query_prenota) {
+if ($query_prenota and ($priv_vedi_tab_prenotazioni != "n" or ($priv_vedi_tab_mesi != "n" and $priv_mod_prenotazioni != "n"))) {
 if ($lista_prenota) {
 $lista_prenota = explode(",",$query_prenota);
 $num_ripeti = count($lista_prenota) - 1;
@@ -347,15 +365,18 @@ $prenotazioni = esegui_query($query_prenota);
 $num_ripeti = numlin_query($prenotazioni);
 $lista_prenota = array();
 for ($num1 = 1 ; $num1 <= $num_ripeti ; $num1++) $lista_prenota[$num1] = risul_query($prenotazioni,($num1 - 1),'idprenota');
+chiudi_query($prenotazioni);
 } # fine else if ($lista_prenota)
 include("./includes/dati_lista_prenota.php");
-} # fine if ($query_prenota)
+} # fine if ($query_prenota and ($priv_vedi_tab_prenotazioni != "n" or...
+
 
 if ($query_clienti and $vedi_clienti != "NO") {
 $clienti = esegui_query($query_clienti);
 $num_ripeti = numlin_query($clienti);
 $lista_clienti = array();
 for ($num1 = 1 ; $num1 <= $num_ripeti ; $num1++) $lista_clienti[$num1] = risul_query($clienti,($num1 - 1),'idclienti');
+chiudi_query($clienti);
 include("./includes/dati_lista_clienti.php");
 } # fine if ($query_clienti and $vedi_clienti != "NO")
 
@@ -444,6 +465,7 @@ if ($foothtm) echo $foothtm;
 
 $pag = $pag_orig;
 } # fine if ($anno_utente_attivato == "SI")
+} # fine else if ($raggiunto_limite)
 } # fine if ($pass == $pass_api)
 else {
 $versione_transazione = prendi_numero_versione($tabletransazioniweb,"idtransazioni","anno");
@@ -464,18 +486,27 @@ esegui_query("insert into $tabletransazioniweb (idtransazioni,tipo_transazione,d
 
 
 
+# Conferma sessione da modulo carte di credito
 if ($session_data and $id_sessione and defined('C_IP_MOD_EXT_CARTE_CREDITO') and C_IP_MOD_EXT_CARTE_CREDITO != "") {
 if ($_SERVER['REMOTE_ADDR']) $REMOTE_ADDR = $_SERVER['REMOTE_ADDR'];
 if ($REMOTE_ADDR == C_IP_MOD_EXT_CARTE_CREDITO or ($REMOTE_ADDR == "::1" and C_IP_MOD_EXT_CARTE_CREDITO == "127.0.0.1")) {
 $cli_pass = 0;
-if ($tweb) $tabelle_lock = array($tableutenti,$tabletransazioniweb);
-else $tabelle_lock = array($tableutenti,$tablesessioni);
-if ($cli_id == "pass" and !$tweb) {
+$cli_presfut = 0;
+# Non fare lock in scrittura sulle stesse tabelle dalle funzioni delle interconnessioni, altrimenti si blocca quando si attiva cc_hd_token
+if ($tweb) $tabelle_lock = array($tabletransazioniweb);
+else $tabelle_lock = array($tablesessioni);
+if (($cli_id == "pass" or $cli_id == "pres_fut") and !$tweb) {
 $anni_esist = esegui_query("select * from $tableanni order by idanni");
 $num_anni = numlin_query($anni_esist);
 unset($anni);
 for ($num1 = 0 ; $num1 < $num_anni ; $num1++) $anni[$num1] = risul_query($anni_esist,$num1,'idanni');
 $anno_corr = $anno_corrente;
+if ($cli_id == "pres_fut") {
+# Mantenere carte degli ultimi 4 mesi (120gg)
+$data_limite_passato = date("Y-m-d",(time() - (120 * 86400) + (C_DIFF_ORE * 3600)));
+$anno_corr = substr($data_limite_passato,0,4);
+} # fine if ($cli_id == "pres_fut")
+else $data_limite_passato = "";
 if ($anni[0] > $anno_corr) $anno_corr = $anni[0];
 if ($anni[($num_anni - 1)] < $anno_corr) $anno_corr = $anni[($num_anni - 1)];
 $altre_tab_lock = array($tableanni);
@@ -501,44 +532,60 @@ $num_lock++;
 $altre_tab_lock[$num_lock] = $tableprivilegi;
 $num_lock++;
 $altre_tab_lock[$num_lock] = $tablerelgruppi;
-} # fine if ($cli_id == "pass" and !$tweb)
+} # fine if (($cli_id == "pass" or $cli_id == "pres_fut") and !$tweb)
 else {
-if ($cli_id) $altre_tab_lock = array($tableclienti,$tablepersonalizza,$tableprivilegi,$tablerelgruppi);
+if (strstr($cli_id,",")) $altre_tab_lock = array($tableclienti,$tablepersonalizza,$tableprivilegi,$tablerelgruppi,$tabletransazioni);
+else {
+if ($cli_id or $priv_r) $altre_tab_lock = array($tableclienti,$tablepersonalizza,$tableprivilegi,$tablerelgruppi);
 else $altre_tab_lock = array($tablepersonalizza);
-} # fine else if ($cli_id == "pass" and !$tweb)
+} # fine else if (strstr($cli_id,","))
+} # fine else if (($cli_id == "pass" or $cli_id == "pres_fut") and !$tweb)
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
+$sessione_trovata = 0;
+if (defined('C_UTENTE_CANC_CC') and $id_sessione == C_UTENTE_CANC_CC and $cli_id == "pres_fut") $sessione_trovata = 1;
+else {
 $minuti_durata_sessione = esegui_query("select valpersonalizza_num from $tablepersonalizza where idpersonalizza = 'minuti_durata_sessione' and idutente = '1'");
 $minuti_durata_sessione = risul_query($minuti_durata_sessione,0,'valpersonalizza_num');
 $limite_sessioni_vecchie = date("Y-m-d H:i:s",(time() - ($minuti_durata_sessione * 60) + (C_DIFF_ORE * 3600)));
 if ($tweb) {
 esegui_query("delete from $tabletransazioniweb where tipo_transazione = 'pay_c' and ultimo_accesso <= '$limite_sessioni_vecchie'");
 $sessione = esegui_query("select * from $tabletransazioniweb where tipo_transazione = 'pay_c' and idtransazioni = '".aggslashdb($id_sessione)."' ");
+$sessione_trovata = numlin_query($sessione);
 } # fine if ($tweb)
 else {
 esegui_query("delete from $tablesessioni where ultimo_accesso <= '$limite_sessioni_vecchie'");
 $sessione = esegui_query("select * from $tablesessioni where idsessioni = '$id_sessione'");
+$sessione_trovata = numlin_query($sessione);
 } # fine else if ($tweb)
-if (numlin_query($sessione) == 1) {
+} # fine else if (defined('C_UTENTE_CANC_CC') and $id_sessione == C_UTENTE_CANC_CC and $cli_id == "pres_fut")
+if ($sessione_trovata) {
 
 @include(C_DATI_PATH."/lingua.php");
 @include(C_DATI_PATH."/tema.php");
+if (defined('C_UTENTE_CANC_CC') and $id_sessione == C_UTENTE_CANC_CC) $id_utente = 1;
+else {
 if ($tweb) {
 $id_utente = "t";
 $lingua[$id_utente] = $lingua[1];
 $tema[$id_utente] = $tema[1];
 } # fine if ($tweb)
 else $id_utente = risul_query($sessione,0,'idutente');
+} # fine else if (defined('C_UTENTE_CANC_CC') and $id_sessione == C_UTENTE_CANC_CC)
 echo "<user_id>$id_utente<user_id>
 <lang>".$lingua[$id_utente]."</lang>
 <theme>".$tema[$id_utente]."</theme>";
+if (defined('C_FILE_CSS_PERS') and C_FILE_CSS_PERS != "" and @is_file(C_FILE_CSS_PERS)) echo "<css_pers>".C_FILE_CSS_PERS."</css_pers>";
+if (defined('C_FILE_MOB_CSS_PERS') and C_FILE_MOB_CSS_PERS != "" and @is_file(C_FILE_MOB_CSS_PERS)) echo "<mob_css_pers>".C_FILE_MOB_CSS_PERS."</mob_css_pers>";
 $idclienti = aggslashdb($cli_id);
 
-if ($cli_id and $id_utente != 1 and !$tweb) {
+if ($priv_r or ($cli_id and $id_utente != 1 and !$tweb)) {
 $privilegi_annuali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '$anno'");
 if (numlin_query($privilegi_annuali_utente) == 0) $anno_utente_attivato = "NO";
 else {
 $anno_utente_attivato = "SI";
 $privilegi_globali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '1'");
+$priv_mod_pers = risul_query($privilegi_globali_utente,0,'priv_mod_pers');
+$priv_gest_pass_cc = substr($priv_mod_pers,5,1);
 $priv_ins_clienti = risul_query($privilegi_globali_utente,0,'priv_ins_clienti');
 $modifica_clienti = "NO";
 if (substr($priv_ins_clienti,1,1) == "s") $modifica_clienti = "SI";
@@ -561,20 +608,39 @@ $num_utenti_gruppo = numlin_query($utenti_gruppo);
 for ($num2 = 0 ; $num2 < $num_utenti_gruppo ; $num2++) $utenti_gruppi[risul_query($utenti_gruppo,$num2,'idutente')] = 1;
 } # fine for $num1
 } # fine if ($prendi_gruppi == "SI")
-} # fine if ($cli_id and $id_utente != 1 and !$tweb)
+} # fine if ($priv_r or ($cli_id and $id_utente != 1 and !$tweb))
 
-if ($cli_id == "pass" and !$tweb) {
+if (($cli_id == "pass" or $cli_id == "pres_fut") and !$tweb) {
+if ($cli_id == "pass") $cli_pass = 1;
+if ($cli_id == "pres_fut") $cli_presfut = 1;
 $cli_id = "";
-$cli_pass = 1;
-} # fine if ($cli_id == "pass" and !$tweb)
+if ($id_utente != 1 and ($modifica_clienti == "PROPRI" or $modifica_clienti == "GRUPPI")) {
+$condizione_utente_canc = "where ( utente_inserimento = '$id_utente'";
+if ($modifica_clienti == "GRUPPI") {
+foreach ($utenti_gruppi as $idut_gr => $val) if ($idut_gr != $id_utente) $condizione_utente_canc .= " or utente_inserimento = '$idut_gr'";
+} # fine if ($modifica_clienti == "GRUPPI")
+$condizione_utente_canc .= " )";
+} # fine if ($id_utente != 1 and ($modifica_clienti == "PROPRI" or $modifica_clienti == "GRUPPI"))
+else $condizione_utente_canc = "";
+} # fine if (($cli_id == "pass" or $cli_id == "pres_fut") and !$tweb)
 
 if ($cli_id and $id_utente != 1) {
+$cli_priv = 0;
 if ($tweb) {
 $idclienti_tweb = risul_query($sessione,0,'dati_transazione14');
 if ($idclienti_tweb == $idclienti) $cli_priv = 1;
-else $cli_priv = 0;
 } # fine if ($tweb)
 else {
+if (strstr($idclienti,",")) {
+$limite_transazioni_vecchie = date("Y-m-d H:i:s",(time() - (15 * 60) + (C_DIFF_ORE * 3600)));
+esegui_query("delete from $tabletransazioni where ultimo_accesso <= '$limite_transazioni_vecchie' and tipo_transazione = 'cn_cc' ");
+$transaz_esist = esegui_query("select * from $tabletransazioni where idsessione = '$id_sessione' and tipo_transazione = 'cn_cc' and dati_transazione1 = '$idclienti' ");
+if (numlin_query($transaz_esist)) {
+$cli_priv = 1;
+esegui_query("delete from $tabletransazioni where idsessione = '$id_sessione' and tipo_transazione = 'cn_cc' and dati_transazione1 = '$idclienti' ");
+} # fine if (numlin_query($transaz_esist))
+} # fine if (strstr($idclienti,","))
+else {
 if ($modifica_clienti == "PROPRI" or $vedi_clienti == "PROPRI") {
 $cliente_proprio = esegui_query("select idclienti from $tableclienti where idclienti = '$idclienti' and utente_inserimento = '$id_utente'");
 if (numlin_query($cliente_proprio) == 0) $modifica_clienti = "NO";
@@ -586,21 +652,13 @@ else $utente_inserimento = risul_query($cliente_proprio,0,'utente_inserimento');
 if (!$utenti_gruppi[$utente_inserimento]) $modifica_clienti = "NO";
 } # fine elseif ($modifica_clienti == "GRUPPI" or $vedi_clienti == "GRUPPI")
 if ($anno_utente_attivato == "SI" and $modifica_clienti != "NO" and $vedi_clienti != "NO" and $idclienti and controlla_num_pos($idclienti) == "SI") $cli_priv = 1;
-else $cli_priv = 0;
+} # fine else if (strstr($idclienti,","))
 } # fine else if ($tweb)
 echo "<cli_priv>$cli_priv</cli_priv>";
 } # fine if ($cli_id and $id_utente != 1)
 
-if ($cli_pass) {
-if ($id_utente != 1 and ($modifica_clienti == "PROPRI" or $modifica_clienti == "GRUPPI")) {
-$condizione_utente_canc = "where ( utente_inserimento = '$id_utente'";
-if ($modifica_clienti == "GRUPPI") {
-while (list($idut_gr,$val) = each($utenti_gruppi)) if ($idut_gr != $id_utente) $condizione_utente_canc .= " or utente_inserimento = '$idut_gr'";
-} # fine if ($modifica_clienti == "GRUPPI")
-$condizione_utente_canc .= " )";
-} # fine if ($id_utente != 1 and ($modifica_clienti == "PROPRI" or $modifica_clienti == "GRUPPI"))
-else $condizione_utente_canc = "";
-$idperiodocorrente = (calcola_id_periodo_corrente($anno_corr,"NO") + 1);
+if ($cli_pass or $cli_presfut) {
+$idperiodocorrente = (calcola_id_periodo_corrente($anno_corr,"NO",$data_limite_passato) + 1);
 unset($cliente_attivo);
 for ($num1 = 0 ; $num1 < $num_anni ; $num1++) {
 $anno_mostra = $anni[$num1];
@@ -618,18 +676,30 @@ for ($num3 = 0 ; $num3 < numlin_query($ospiti) ; $num3++) $cliente_attivo[risul_
 } # fine for $num2
 } # fine ($anno_mostra >= $anno_corr)
 } # fine for $num1
+if ($cli_pass) {
 $clienti = esegui_query("select * from $tableclienti $condizione_utente_canc");
 $num_clienti = numlin_query($clienti);
-$num_canc = 0;
-$limite_canc = 0;
+$lista_clienti_canc = "";
 for ($num1 = 0; $num1 < $num_clienti; $num1++) {
 $idclienti = risul_query($clienti,$num1,'idclienti');
 if (!$cliente_attivo[$idclienti]) $lista_clienti_canc .= ",$idclienti";
 } # fine for $num1
 echo "<cli_pass>".substr($lista_clienti_canc,1)."</cli_pass>";
 } # fine if ($cli_pass)
+if ($cli_presfut) {
+$lista_clienti_att = "";
+foreach ($cliente_attivo as $idcli_at => $val) $lista_clienti_att .= ",$idcli_at";
+echo "<cli_presfut>".substr($lista_clienti_att,1).";</cli_presfut>";
+} # fine if ($cli_presfut)
+} # fine if ($cli_pass or $cli_presfut)
 
-} # fine if (numlin_query($sessione) == 1)
+if ($priv_r) {
+$val_priv_r = "";
+if ($priv_r == "priv_gest_pass_cc") $val_priv_r = $priv_gest_pass_cc;
+if ($val_priv_r) echo "<privr_$priv_r>$val_priv_r</privr_$priv_r>";
+} # fine if ($priv_r)
+
+} # fine if ($sessione_trovata)
 unlock_tabelle($tabelle_lock);
 } # fine if ($REMOTE_ADDR == C_IP_MOD_EXT_CARTE_CREDITO or ($REMOTE_ADDR == "::1" and C_IP_MOD_EXT_CARTE_CREDITO == "127.0.0.1"))
 exit();
@@ -639,4 +709,77 @@ exit();
 
 
 
+# Azioni da modulo carte di credito
+if ($azione and defined('C_IP_MOD_EXT_CARTE_CREDITO') and C_IP_MOD_EXT_CARTE_CREDITO != "") {
+if ($_SERVER['REMOTE_ADDR']) $REMOTE_ADDR = $_SERVER['REMOTE_ADDR'];
+if ($REMOTE_ADDR == C_IP_MOD_EXT_CARTE_CREDITO or ($REMOTE_ADDR == "::1" and C_IP_MOD_EXT_CARTE_CREDITO == "127.0.0.1")) {
+
+
+if ($azione == "pull_xml" and $tipo_ic == "boo" and $valore_xml and $token) {
+
+$file_interconnessioni = C_DATI_PATH."/dati_interconnessioni.php";
+if (@is_file($file_interconnessioni)) {
+include($file_interconnessioni);
+if (@is_array($ic_present)) {
+unset($interconnection_name);
+$funz_import_reservations = "";
+
+$interconn_dir = opendir("./includes/interconnect/");
+while ($mod_ext = readdir($interconn_dir)) {
+if ($mod_ext != "." and $mod_ext != ".." and $mod_ext == $tipo_ic.$ord_ic and @is_dir("./includes/interconnect/$mod_ext")) {
+include("./includes/interconnect/$mod_ext/name.php");
+if ($ic_present[$interconnection_name] == "SI") {
+include("./includes/interconnect/$mod_ext/functions_import.php");
+$funz_import_reservations = "import_reservations_".$interconnection_func_name;
+} # fine if ($ic_present[$interconnection_name] == "SI")
+break;
+} # fine if ($mod_ext != "." and $mod_ext != ".." and $mod_ext == $tipo_ic.$ord_ic and...
+} # fine while ($mod_ext = readdir($interconn_dir))
+closedir($interconn_dir);
+if ($funz_import_reservations) {
+
+if (substr(C_URL_PULL_TOKEN,0,17) == "https://localhost") $token_res_id = file(C_URL_PULL_TOKEN."boo$token.php",false,stream_context_create(array("ssl" => array("verify_peer" => true,"allow_self_signed" => true))));
+else $token_res_id = @file(C_URL_PULL_TOKEN."boo$token.php");
+if (is_array($token_res_id)) $token_res_id = trim(implode("",$token_res_id));
+else $token_res_id = "";
+if (stristr($valore_xml,"<id>$token_res_id<")) {
+
+@include(C_DATI_PATH."/lingua.php");
+$lingua_mex = $lingua[1];
+$id_utente_sessione = "-1";
+$adesso = $anno.date("mdHis",(time() + (C_DIFF_ORE * 3600)));
+$versione_unica = prendi_numero_versione($tableversioni);
+list($usec, $sec) = explode(' ', microtime());
+mt_srand((float) $sec + ((float) $usec * 100000));
+$val_casuale = mt_rand(100000,999999);
+$id_sessione = $adesso.$val_casuale.$versione_unica;
+$ultimo_accesso = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
+if ($_SERVER['REMOTE_ADDR']) $REMOTE_ADDR = $_SERVER['REMOTE_ADDR'];
+$REMOTE_ADDR = aggslashdb($REMOTE_ADDR);
+if ($_SERVER['REMOTE_PORT']) $REMOTE_PORT = $_SERVER['REMOTE_PORT'];
+$REMOTE_PORT = aggslashdb($REMOTE_PORT);
+if ($_SERVER['HTTP_USER_AGENT']) $HTTP_USER_AGENT = $_SERVER['HTTP_USER_AGENT'];
+$HTTP_USER_AGENT = aggslashdb($HTTP_USER_AGENT);
+if ($_SERVER['HTTPS'] == "on" or $_SERVER['SERVER_PORT'] == "443") $tipo_conn = "HTTPS";
+else $tipo_conn = "HTTP";
+esegui_query("insert into $tablesessioni (idsessioni,idutente,indirizzo_ip,tipo_conn,user_agent,ultimo_accesso) values ('$id_sessione','$id_utente_sessione','$REMOTE_ADDR','$tipo_conn','$HTTP_USER_AGENT','$ultimo_accesso')","",1);
+$id_utente_origi = $id_utente;
+$id_utente = 1;
+$testo = $funz_import_reservations("","",$file_interconnessioni,$anno,$PHPR_TAB_PRE,2,$id_utente,$HOSTNAME,$valore_xml);
+$id_utente = $id_utente_origi;
+
+} # fine if (stristr($valore_xml,"<id>$token_res_id<"))
+
+} # fine if ($funz_import_reservations)
+} # fine if (@is_array($ic_present))
+} # fine if (@is_file($file_interconnessioni))
+} # fine if ($azione == "pull_xml" and $tipo_ic == "boo" and $valore_xml and $token)
+
+
+} # fine if ($REMOTE_ADDR == C_IP_MOD_EXT_CARTE_CREDITO or ($REMOTE_ADDR == "::1" and C_IP_MOD_EXT_CARTE_CREDITO == "127.0.0.1"))
+} # fine if ($azione and defined('C_IP_MOD_EXT_CARTE_CREDITO') and C_IP_MOD_EXT_CARTE_CREDITO != "")
+
+
+
+
 ?>
