@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -29,7 +29,7 @@ if (function_exists('ini_set')) @ini_set('opcache.enable',0);
 $pag = "creadb.php";
 $titolo = "HotelDruid: Crea Database";
 
-if (C_CREA_ULTIMO_ACCESSO != "SI" or !@is_file(C_DATI_PATH."/ultimo_accesso")) {
+if (!defined('C_CREA_ULTIMO_ACCESSO') or C_CREA_ULTIMO_ACCESSO != "SI" or !@is_file(C_DATI_PATH."/ultimo_accesso")) {
 
 unset($numconnessione);
 unset($PHPR_TAB_PRE);
@@ -57,7 +57,7 @@ return $messaggio;
 } # fine function mex2
 
 
-if (C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO") $creabase = 1;
+if (defined('C_UTILIZZA_SEMPRE_DEFAULTS') and C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO") $creabase = 1;
 
 
 
@@ -73,7 +73,7 @@ if (($tipo_db == "postgresql" and !@function_exists('pg_connect')) or ($tipo_db
 if ($tipo_db == "sqlite") {
 if (!@class_exists('SQLite3')) $carica_estensione == "SI";
 } # fine if ($tipo_db == "sqlite")
-if (C_UTILIZZA_SEMPRE_DEFAULTS == "SI" or C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO") {
+if (defined('C_UTILIZZA_SEMPRE_DEFAULTS') and (C_UTILIZZA_SEMPRE_DEFAULTS == "SI" or C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO")) {
 $tipo_db = C_CREADB_TIPODB;
 if ($tipo_db == "mysql" and @function_exists('mysqli_connect')) $tipo_db = "mysqli";
 $database_phprdb = C_CREADB_NOMEDB;
@@ -85,7 +85,7 @@ if (!$password_phprdb) $password_phprdb = C_CREADB_PASS;
 if (C_CREADB_ESTENSIONE) $carica_estensione = C_CREADB_ESTENSIONE;
 $tempdatabase = C_CREADB_TEMPDB;
 $prefisso_tab = C_CREADB_PREFISSO_TAB;
-} # fine if (C_UTILIZZA_SEMPRE_DEFAULTS == "SI" or C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO")
+} # fine if (defined('C_UTILIZZA_SEMPRE_DEFAULTS') and (C_UTILIZZA_SEMPRE_DEFAULTS == "SI" or C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO"))
 if (!controlla_num_pos($numletti) == "NO") $numletti = 0;
 if ((!$numappartamenti and !$numletti) or controlla_num_pos($numappartamenti) == "NO") $numappartamenti = 5;
 
@@ -260,7 +260,7 @@ esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersona
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('metodi_pagamento','1','')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('origini_prenota','1','')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('attiva_checkin','1','NO')");
-esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('mostra_quadro_disp','1','')");
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('mostra_quadro_disp','1','reg2')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('ultime_sel_ins_prezzi','1','')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('subordinazione','1','NO')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('percorso_cartella_modello','1','".C_DATI_PATH."')");
@@ -432,21 +432,21 @@ fwrite($fileaperto,"<?php
 fclose($fileaperto);
 $fileaperto = fopen(C_DATI_PATH."/versione.php","w+");
 fwrite($fileaperto,"<?php
-define(C_VERSIONE_ATTUALE,".C_PHPR_VERSIONE_NUM.");
-define(C_DIFF_ORE,0);
+define('C_VERSIONE_ATTUALE',".C_PHPR_VERSIONE_NUM.");
+define('C_DIFF_ORE',0);
 ?>");
 fclose($fileaperto);
 
 include("./includes/funzioni_relutenti.php");
 aggiorna_relutenti("","SI","","",$id_utente,$id_utente,"","","","","","","","nazione","nazioni",$tablenazioni,$tablerelutenti);
 aggiorna_relutenti("","SI","","",$id_utente,$id_utente,"","","","","","","","regione","regioni",$tableregioni,$tablerelutenti,"nazione","nazioni",$tablenazioni);
-if (C_CREADB_CITTA_DEFAULT == "SI") aggiorna_relutenti("","SI","","",$id_utente,$id_utente,"","","","","","","","citta","citta",$tablecitta,$tablerelutenti,"regione","regioni",$tableregioni);
+if (defined('C_CREADB_CITTA_DEFAULT') and C_CREADB_CITTA_DEFAULT == "SI") aggiorna_relutenti("","SI","","",$id_utente,$id_utente,"","","","","","","","citta","citta",$tablecitta,$tablerelutenti,"regione","regioni",$tableregioni);
 aggiorna_relutenti("","SI","","",$id_utente,$id_utente,"","","","","","","","documentoid","documentiid",$tabledocumentiid,$tablerelutenti);
 aggiorna_relutenti("","SI","","",$id_utente,$id_utente,"","","","","","","","parentela","parentele",$tableparentele,$tablerelutenti);
 
-if (C_NASCONDI_MARCA == "SI" and @is_file(C_CARTELLA_CREA_MODELLI."/index.html")) @unlink(C_CARTELLA_CREA_MODELLI."/index.html");
+if (defined('C_NASCONDI_MARCA') and C_NASCONDI_MARCA == "SI" and defined('C_CARTELLA_CREA_MODELLI') and @is_file(C_CARTELLA_CREA_MODELLI."/index.html")) @unlink(C_CARTELLA_CREA_MODELLI."/index.html");
 
-if (C_UTILIZZA_SEMPRE_DEFAULTS != "AUTO") {
+if (!defined('C_UTILIZZA_SEMPRE_DEFAULTS') or C_UTILIZZA_SEMPRE_DEFAULTS != "AUTO") {
 # seconda form di inserimento (appartamenti).
 echo "<br>".mex2("Inserisci ora i dati sugli appartamenti",'unit.php',$lingua)." (<b>".mex2("almeno il numero, diverso per ogni appartamento",'unit.php',$lingua)."</b>).<br>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"creadb.php\"><div>
@@ -499,7 +499,7 @@ echo "<div style=\"text-align: center;\">";
 #<input type=\"checkbox\" name=\"assegna_vicini_np\" value=\"SI\">Devono essere anche sullo stesso piano.<br>";
 echo "<input class=\"sbutton\" type=\"submit\" name=\"insappartamenti\" value=\"".mex2("Inserisci i dati sugli appartamenti",'unit.php',$lingua)."\">
 </div><br></div></form>";
-} # fine if (C_UTILIZZA_SEMPRE_DEFAULTS != "AUTO")
+} # fine if (!defined('C_UTILIZZA_SEMPRE_DEFAULTS') or C_UTILIZZA_SEMPRE_DEFAULTS != "AUTO")
 else $insappartamenti = 1;
 
 } # fine if ($fileaperto = @fopen(C_DATI_PATH"/dati_connessione.php","a+"))
@@ -618,12 +618,12 @@ else {
 if ($num_camera_l) $num_app_max = $numappartamenti + count($lista_camere_letti) - 1;
 else $num_app_max = $numappartamenti + ceil((double) $numletti / 26);
 } # fine else if (!$numletti)
-if (C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO" and $num_app_max < 10) $num_app_max = 10;
+if (defined('C_UTILIZZA_SEMPRE_DEFAULTS') and C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO" and $num_app_max < 10) $num_app_max = 10;
 
 for ($num = 1 ; $num <= ($numappartamenti + $numletti) ; $num = $num + 1) {
 $numapp = "numapp" . $num;
 $numapp = $$numapp;
-if (C_UTILIZZA_SEMPRE_DEFAULTS == "SI" or C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO") {
+if (defined('C_UTILIZZA_SEMPRE_DEFAULTS') and (C_UTILIZZA_SEMPRE_DEFAULTS == "SI" or C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO")) {
 if ($num <= $numappartamenti) $numapp = (string) substr($zeri,0,(strlen($num_app_max) - strlen($num))).$num;
 else {
 if ($pos_lettera_tot == 0) {
@@ -657,7 +657,7 @@ if (!$suff_lettera) $suff_lettera = "a";
 else $suff_lettera = substr(strstr($lettere,$suff_lettera),1,1);
 } # fine if ($pos_lettera >= 26)
 } # fine else if ($num <= $numappartamenti)
-} # fine if (C_UTILIZZA_SEMPRE_DEFAULTS == "SI" or C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO")
+} # fine if (defined('C_UTILIZZA_SEMPRE_DEFAULTS') and (C_UTILIZZA_SEMPRE_DEFAULTS == "SI" or C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO"))
 $numapp = str_replace (",","",$numapp);
 if (str_replace (" ","",$numapp) == "") $numapp = str_replace (" ","_",$numapp);
 $numapp = trim($numapp);
@@ -728,7 +728,7 @@ esegui_query("update $tableappartamenti set app_vicini = '$app_vicini' where ida
 } # fine for $num
 } # fine if ($num_camera_l)
 
-if (C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO" and @is_file(C_DATI_PATH."/ini.php")) {
+if (defined('C_UTILIZZA_SEMPRE_DEFAULTS') and C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO" and @is_file(C_DATI_PATH."/ini.php")) {
 include(C_DATI_PATH."/ini.php");
 $admin = "";
 if (defined('C_ADMIN_NAME')) $admin = C_ADMIN_NAME;
@@ -758,11 +758,11 @@ fclose($fileaperto);
 } # fine if (strcmp($passw,""))
 } # fine if (strcmp($admin,""))
 @unlink(C_DATI_PATH."/ini.php");
-} # fine if (C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO" and @is_file(C_DATI_PATH."/ini.php"))
+} # fine if (defined('C_UTILIZZA_SEMPRE_DEFAULTS') and C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO" and @is_file(C_DATI_PATH."/ini.php"))
 
 $tablemessaggi = $PHPR_TAB_PRE."messaggi";
 $testo = "<div style=\"max-width: 600px; line-height: 1.1;\">";
-if (C_NASCONDI_MARCA != "SI") $testo .= "<h4>".mex("Benvenuto a HotelDruid!",$pag)."</h4><br>";
+if (!defined('C_NASCONDI_MARCA') or C_NASCONDI_MARCA != "SI") $testo .= "<h4>".mex("Benvenuto a HotelDruid!",$pag)."</h4><br>";
 $testo .= "".mex("Questi sono alcuni semplici passi che puoi seguire per configurare le funzionalità di base di HotelDruid",$pag).":<br>
 <ul style=\"line-height: 1.2;\">
 <li>".mex("Inserisci le informazioni sugli appartamenti dalla",'unit.php')."
@@ -781,7 +781,7 @@ $testo .= "".mex("Questi sono alcuni semplici passi che puoi seguire per configu
  \"<em><b><a href=\"./personalizza.php?<sessione>\">".mex("configura e personalizza",$pag)."</a></b></em>\"
  ".mex("per cambiare il nome della valuta, abilitare la registrazione delle entrate, inserire i metodi di pagamento, ed impostare molte altre opzioni",$pag).".<br><br></li>
 </ul></div>";
-if (C_NASCONDI_MARCA == "SI") $testo = str_replace("HotelDruid",mex("questo programma",$pag),$testo);
+if (defined('C_NASCONDI_MARCA') and C_NASCONDI_MARCA == "SI") $testo = str_replace("HotelDruid",mex("questo programma",$pag),$testo);
 $testo = aggslashdb($testo);
 $datainserimento = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 esegui_query("insert into $tablemessaggi (idmessaggi,tipo_messaggio,idutenti,idutenti_visto,datavisione,mittente,testo,datainserimento) values ('1','sistema',',1,',',1,','$datainserimento','1','$testo','$datainserimento')");
@@ -791,12 +791,12 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"inizio.php\"><div>
 <input type=\"hidden\" name=\"nuovo_mess\" value=\"1\">
 <input class=\"sbutton\" type=\"submit\" name=\"ok\" value=\"OK\"><br>
 </div></form>";
-if (C_CREA_ULTIMO_ACCESSO == "SI") {
+if (defined('C_CREA_ULTIMO_ACCESSO') and C_CREA_ULTIMO_ACCESSO == "SI") {
 $fileaperto = @fopen(C_DATI_PATH."/ultimo_accesso","w+");
 @fwrite($fileaperto,date("d-m-Y H:i:s"));
 @fclose($fileaperto);
 @chmod(C_DATI_PATH."/ultimo_accesso",0644);
-} # fine if (C_CREA_ULTIMO_ACCESSO == "SI")
+} # fine if (defined('C_CREA_ULTIMO_ACCESSO') and C_CREA_ULTIMO_ACCESSO == "SI")
 } # fine if ($insappartamenti and !@is_file(C_DATI_PATH."/selectappartamenti.php"))
 
 
@@ -882,7 +882,7 @@ else include("./includes/foot.php");
 } # fine if ($id_utente and $id_utente == 1)
 
 
-} # fine if (CREA_ULTIMO_ACCESSO != "SI" or !@is_file(C_DATI_PATH."/ultimo_accesso"))
+} # fine if (!defined('C_CREA_ULTIMO_ACCESSO') or CREA_ULTIMO_ACCESSO != "SI" or !@is_file(C_DATI_PATH."/ultimo_accesso"))
 
 
 ?>
