@@ -428,7 +428,9 @@ $aggiorna_ic_tar = 1;
 } # fine if ($regola_4)
 
 if ($tabelle_lock) unlock_tabelle($tabelle_lock);
-echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"crearegole.php\"><div>
+if ($origine) $azione = $origine;
+else $azione = "crearegole.php";
+echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$azione\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <button class=\"gobk\" type=\"submit\"><div>".mex("Torna indietro",$pag)."</div></button>";
@@ -452,6 +454,27 @@ else {
 echo "<br><h4 id=\"h_irul\"><span>".mex("Inserisci le regole di assegnazione per le prenotazioni dell'anno",$pag)." $anno
 </span></h4><br><hr style=\"width: 95%\">";
 
+$mostra_solo_regola = 0;
+if ($origine == "tab_reg2") {
+$mostra_solo_regola = 2;
+$origine = "visualizza_tabelle.php?tipo_tabella=regole#hreg2";
+} # fine if ($origine == "tab_reg2")
+if ($origine == "tab_tariffa") {
+if ($tipotariffa_regola2) $mostra_solo_regola = 2;
+if ($tipotariffa_regola4) $mostra_solo_regola = 4;
+$origine = "tab_tariffe.php?numtariffa1=".substr($tipotariffa_regola2.$tipotariffa_regola4,7);
+} # fine if ($origine == "tab_tariffa")
+if (substr($origine,0,3) == "ic_") {
+$orig = explode("_",$origine);
+if ($orig[1] == "r2") $mostra_solo_regola = 2;
+if ($orig[1] == "r4") $mostra_solo_regola = 4;
+$origine = "interconnessioni.php#".$orig[2];
+} # fine if (substr($origine,0,3) == "ic_")
+$rigatariffe = esegui_query("select * from $tablenometariffe where idntariffe = 1 ");
+$numero_tariffe = risul_query($rigatariffe,0,'nomecostoagg');
+
+
+if (!$mostra_solo_regola or $mostra_solo_regola == 1) {
 $inizio_select = "";
 $fine_select = "";
 $oggi = date("Y-m-d",(time() + (C_DIFF_ORE * 3600)));
@@ -491,8 +514,6 @@ echo "<br>".mex("motivazione",$pag).":
 <input type=\"hidden\" name=\"regola_1_tar\" value=\"1\">
 ".mex("Chiudi",$pag)." <select name=\"tipotariffa\" id=\"t1\">
 <option value=\"\" selected>----</option>";
-$rigatariffe = esegui_query("select * from $tablenometariffe where idntariffe = 1 ");
-$numero_tariffe = risul_query($rigatariffe,0,'nomecostoagg');
 for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa = $numtariffa + 1) {
 $tariffa = "tariffa".$numtariffa;
 $tariffa_vedi = mex("tariffa","prenota.php").$numtariffa;
@@ -519,8 +540,12 @@ echo "<br>".mex("motivazione",$pag).":
 <input type=\"hidden\" name=\"inserisci\" value=\"SI\">
 <button class=\"crul\" type=\"submit\" name=\"canc_regola_1\" value=\"1\"><div>".mex("Cancella tutte le regole di questo tipo",$pag)."</div></button>
 </div></form>
-<hr style=\"width: 95%\"><a name=\"regola2\"></a>
+<hr style=\"width: 95%\">";
+} # fine if (!$mostra_solo_regola or $mostra_solo_regola == 1)
 
+
+if (!$mostra_solo_regola or $mostra_solo_regola == 2) {
+echo "<a name=\"regola2\"></a>
 <script type=\"text/javascript\">
 <!--
 var nreg = '';
@@ -676,7 +701,7 @@ $num_appartamenti = numlin_query($appartamenti);
 $num_col = 4;
 $n_col = 1;
 $array_app = "";
-$lista_maxocc = "";
+$lista_maxocc = array();
 for ($num1 = 0 ; $num1 < $num_appartamenti ; $num1++) {
 $lung = strlen(risul_query($appartamenti,$num1,'idappartamenti'));
 if ($lung > 6) $num_col = 3;
@@ -713,7 +738,7 @@ echo "<tr><td colspan=\"$num_col\">\
 ";
 ksort($lista_maxocc);
 reset($lista_maxocc);
-while (list($key, $val) = each($lista_maxocc)) {
+foreach ($lista_maxocc as $key => $val) {
 $persone_casa = $key;
 if ($persone_casa != $ultime_persone_casa) {
 $array_maxocc .= "lapp_maxocc[$persone_casa] = \"".substr($val,0,-1)."\";
@@ -722,7 +747,7 @@ $ultime_persone_casa = $persone_casa;
 echo "<option value=\"$persone_casa\">$persone_casa<\/option>\
 ";
 } # fine if ($persone_casa != $ultimepersone_casa)
-} # fine while (list($key, $val) = each($dati_app[maxocc]))
+} # fine foreach ($lista_maxocc as $key => $val)
 
 echo "<\/select>\
 ".mex(" persone",'unit.php')."<\/small>\
@@ -746,8 +771,9 @@ $array_maxocc
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"inserisci\" value=\"SI\">
-<input type=\"hidden\" name=\"regola_2\" value=\"SI\">
-".mex("Quando si sceglie la tariffa",$pag)."
+<input type=\"hidden\" name=\"regola_2\" value=\"SI\">";
+if ($origine) echo "<input type=\"hidden\" name=\"origine\" value=\"$origine\">";
+echo "".mex("Quando si sceglie la tariffa",$pag)."
 <select name=\"tipotariffa\" id=\"t2\" onchange=\"aggiorna_val_reg2()\">
 <option value=\"\" selected>----</option>";
 for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa = $numtariffa + 1) {
@@ -798,8 +824,9 @@ echo "<br><br>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"inserisci\" value=\"SI\">
-<input type=\"hidden\" name=\"regola_2b\" value=\"SI\">
-".mex("Eccezioni alla regola",$pag)." 2:<br>
+<input type=\"hidden\" name=\"regola_2b\" value=\"SI\">";
+if ($origine) echo "<input type=\"hidden\" name=\"origine\" value=\"$origine\">";
+echo "".mex("Eccezioni alla regola",$pag)." 2:<br>
 ".mex("Quando si sceglie la tariffa",$pag)."
 <select name=\"tipotariffa\" id=\"t2b\" onchange=\"aggiorna_val_reg2b()\">
 <option value=\"\" selected>----</option>
@@ -833,11 +860,12 @@ document.write('<div id=\"tab_appb\" style=\"visibility: hidden;\"><\/div>');
 -->
 </script>
 </div></form>
-
-<hr style=\"width: 95%\">
+<hr style=\"width: 95%\">";
+} # fine if (!$mostra_solo_regola or $mostra_solo_regola == 2)
 
 
-<script type=\"text/javascript\">
+if (!$mostra_solo_regola or $mostra_solo_regola == 3) {
+echo "<script type=\"text/javascript\">
 <!--
 function aggiorna_val_reg3 () {
 var sel_tar = document.getElementById(\"t3\");
@@ -913,7 +941,10 @@ sel_box.disabled = true;
 <button class=\"irul\" type=\"submit\" name=\"regola_3\" value=\"1\"><div>".mex("Inserisci o modifica la regola",$pag)." 3</div></button>
 </div></div></form><hr style=\"width: 95%\">";
 } # fine if ($num_tutti_utenti > 1)
+} # fine if (!$mostra_solo_regola or $mostra_solo_regola == 3)
 
+
+if (!$mostra_solo_regola or $mostra_solo_regola == 4) {
 echo "
 <script type=\"text/javascript\">
 <!--
@@ -942,8 +973,9 @@ echo "}
 <form accept-charset=\"utf-8\" method=\"post\" action=\"crearegole.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
-<input type=\"hidden\" name=\"inserisci\" value=\"SI\">
-".mex("Quando si sceglie la tariffa",$pag)."
+<input type=\"hidden\" name=\"inserisci\" value=\"SI\">";
+if ($origine) echo "<input type=\"hidden\" name=\"origine\" value=\"$origine\">";
+echo mex("Quando si sceglie la tariffa",$pag)."
 <select name=\"tipotariffa\" id=\"t4\" onchange=\"aggiorna_val_reg4()\">
 <option value=\"\" selected>----</option>";
 for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa = $numtariffa + 1) {
@@ -979,7 +1011,10 @@ aggiorna_val_reg4();
 </script>
 ";
 } # fine if ($tipotariffa_regola4 and...
+} # fine if (!$mostra_solo_regola or $mostra_solo_regola == 4)
 
+
+if (!$mostra_solo_regola) {
 echo "<table><tr><td style=\"height: 6px;\"></td></tr></table>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"creaprezzi.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
@@ -996,9 +1031,12 @@ echo "<table><tr><td style=\"height: 6px;\"></td></tr></table>
 <button class=\"aexc\" type=\"submit\"><div>".mex("inserisci",'creaprezzi.php')."</div></button>.
 <table><tr><td style=\"height: 6px;\"></td></tr></table>
 </div></form><hr style=\"width: 95%\">";
+} # fine if (!$mostra_solo_regola)
 
-echo "<div style=\"text-align: center;\"><br>
-<form accept-charset=\"utf-8\" method=\"post\" action=\"visualizza_tabelle.php\"><div>
+
+echo "<div style=\"text-align: center;\"><br>";
+if (!$origine) {
+echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"visualizza_tabelle.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"tipo_tabella\" value=\"regole\">
@@ -1008,7 +1046,17 @@ echo "<div style=\"text-align: center;\"><br>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <button class=\"bkmm\" type=\"submit\"><div>".mex("Torna al menù principale",$pag)."</div></button>
-<br></div></form><br></div>";
+<br></div></form>";
+} # fine if (!$origine)
+else {
+echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$origine\"><div>
+<input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<button class=\"gobk\" type=\"submit\"><div>".mex("Torna indietro",$pag)."</div></button>
+<br></div></form>";
+} # fine else if (!$origine)
+echo "<br></div>";
+
 
 
 } # fine else if ($inserisci)
