@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -55,7 +55,7 @@ if ($modifica_utenti) {
 $mostra_tabella_iniziale = "NO";
 $tabelle_lock = array($tableutenti,$tablesessioni);
 $tabelle_lock = lock_tabelle($tabelle_lock);
-if (C_RESTRIZIONI_DEMO_ADMIN == "SI") $cond_escludi_admin = " where idutenti != '1'";
+if (defined('C_RESTRIZIONI_DEMO_ADMIN') and C_RESTRIZIONI_DEMO_ADMIN == "SI") $cond_escludi_admin = " where idutenti != '1'";
 else $cond_escludi_admin = "";
 $lista_utenti = esegui_query("select idutenti,nome_utente,password,tipo_pass from $tableutenti$cond_escludi_admin order by idutenti");
 
@@ -87,7 +87,7 @@ echo "<input type=\"hidden\" name=\"nome$id\" value=\"".${"nome".$id}."\">";
 } # fine if ($nome != ${"nome".$id} and...
 $n_tipo_pass = ${"tipo_pass".$id};
 if ($n_tipo_pass != "5" and $n_tipo_pass != "t") $n_tipo_pass = "n";
-if (C_DISABILITA_PASS_ADMIN == "NO" and $id == 1 and $tipo_pass != "n" and $n_tipo_pass == "n") $n_tipo_pass = $tipo_pass;
+if (defined('C_DISABILITA_PASS_ADMIN') and C_DISABILITA_PASS_ADMIN == "NO" and $id == 1 and $tipo_pass != "n" and $n_tipo_pass == "n") $n_tipo_pass = $tipo_pass;
 if ($tipo_pass != $n_tipo_pass) {
 $cambiato = "SI";
 echo mex("Il <b>login</b> dell'utente",$pag)." <b>$id</b>";
@@ -232,7 +232,7 @@ $nuovo_id = risul_query($nuovo_id,0,0) + 1;
 $nomi_contr = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'nomi_contratti' and idutente = '1' ");
 $nomi_contr = risul_query($nomi_contr,0,'valpersonalizza');
 esegui_query("insert into $tableutenti (idutenti,nome_utente,tipo_pass,datainserimento,hostinserimento) values ('$nuovo_id','$nome','n','$datainserimento','$HOSTNAME')");
-esegui_query("insert into $tableprivilegi (idutente,anno,casse_consentite,priv_mod_pers,priv_ins_clienti,prefisso_clienti,priv_messaggi,priv_inventario) values ('$nuovo_id','1','n,','nnnnn','nnnss','n,','nn','nnnnnnnnn')");
+esegui_query("insert into $tableprivilegi (idutente,anno,casse_consentite,priv_mod_pers,priv_ins_clienti,prefisso_clienti,priv_messaggi,priv_inventario) values ('$nuovo_id','1','n,','nnnnnn','nnnss','n,','nn','nnnnnnnnn')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('col_tab_tutte_prenota','$nuovo_id','nu#@&cg#@&in#@&fi#@&tc#@&ca#@&pa#@&ap#@&pe#@&co')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('rig_tab_tutte_prenota','$nuovo_id','to#@&ta#@&ca#@&pc')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('dati_struttura','$nuovo_id','#@&#@&#@&#@&#@&#@&#@&#@&#@&#@&#@&')");
@@ -243,7 +243,7 @@ esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersona
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('costi_agg_in_tab_prenota','$nuovo_id','')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('aggiunta_tronca_nomi_tab1','$nuovo_id','-2')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('linee_ripeti_date_tab_mesi','$nuovo_id','25')");
-esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('mostra_giorni_tab_mesi','$nuovo_id','NO')");
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('mostra_giorni_tab_mesi','$nuovo_id','SI')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('colori_tab_mesi','$nuovo_id','#70C6D4,#FFD800,#FF9900,#FF3115')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('num_linee_tab2_prenota','$nuovo_id','30')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('nomi_contratti','$nuovo_id','".aggslashdb($nomi_contr)."')");
@@ -266,7 +266,7 @@ esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersona
 $filelock = crea_lock_file(C_DATI_PATH."/lingua.php");
 include(C_DATI_PATH."/lingua.php");
 $file_lingua = @file(C_DATI_PATH."/lingua.php");
-$linee = "";
+$linee = array();
 $num_lin = 0;
 for ($num1 = 0 ; $num1 < count($file_lingua) ; $num1++) {
 if (substr($file_lingua[$num1],0,2) == "?>") {
@@ -283,7 +283,7 @@ distruggi_lock_file($filelock,C_DATI_PATH."/lingua.php");
 $filelock = crea_lock_file(C_DATI_PATH."/tema.php");
 include(C_DATI_PATH."/tema.php");
 $file_tema = @file(C_DATI_PATH."/tema.php");
-unset($linee);
+$linee = array();
 $num_lin = 0;
 for ($num1 = 0 ; $num1 < count($file_tema) ; $num1++) {
 if (substr($file_tema[$num1],0,2) == "?>") {
@@ -317,7 +317,7 @@ $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 $dati_utente = esegui_query("select * from $tableutenti where idutenti = '".aggslashdb($id_utente_pass)."' ");
 if (numlin_query($dati_utente) != 1) $continua = "NO";
 else $nome_utente = risul_query($dati_utente,0,'nome_utente');
-if ($id_utente_pass == 1 and C_RESTRIZIONI_DEMO_ADMIN == "SI") $continua = "NO";
+if ($id_utente_pass == 1 and defined('C_RESTRIZIONI_DEMO_ADMIN') and C_RESTRIZIONI_DEMO_ADMIN == "SI") $continua = "NO";
 if ($continua == "SI" and ($prima_pass != $seconda_pass or $prima_pass == "" or $prima_pass != str_replace("&","",$prima_pass))) {
 unset($continua);
 echo mex("Le nuove password non coincidono",$pag).".<br><br>";
@@ -722,6 +722,7 @@ echo "<div style=\"text-align: center;\">
 <form accept-charset=\"utf-8\" method=\"post\" action=\"gestione_utenti.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<div class=\"tab_cont\">
 <table class=\"usrs\" style=\"margin-left: auto; margin-right: auto;\" border=1 cellspacing=1 cellpadding=1>
 <tr style=\"background-color: $t1color;\"><td align=\"center\">".mex("N°",$pag)."</td>
 <td align=\"center\">".mex("nome",$pag)."</td>
@@ -749,7 +750,7 @@ if ($id == 1) echo "*";
 echo "</td>
 <td align=\"center\" valign=\"middle\"><input type=\"text\" name=\"nome$id\" size=\"15\" value=\"$nome\"></td>
 <td align=\"center\" valign=\"middle\"><select name=\"tipo_pass$id\">";
-if (C_DISABILITA_PASS_ADMIN != "NO" or $id != 1 or $disab_sel) echo "<option value=\"n\"$disab_sel>".mex("disabilitato",$pag)."</option>";
+if (!defined('C_DISABILITA_PASS_ADMIN') or C_DISABILITA_PASS_ADMIN != "NO" or $id != 1 or $disab_sel) echo "<option value=\"n\"$disab_sel>".mex("disabilitato",$pag)."</option>";
 #echo "<option value=\"t\"$testo_sel>".mex("password conservata in chiaro",$pag)."</option>";
 echo "<option value=\"5\"$md5_sel>".mex("password criptata con md5",$pag)."</option>";
 #echo "<option value=\"c\"$mcrypt_sel>".mex("password criptata con mcrypt",$pag)."</option>
@@ -787,7 +788,7 @@ if ($dati_collegati != "SI") echo "<br><a href=\"./gestione_utenti.php?anno=$ann
 echo "</small></td></tr>";
 } # fine for $num1
 
-echo "</table>
+echo "</table></div>
 <small>* ".mex("Amministratore",$pag).".&nbsp;&nbsp;&nbsp;
 ** ".mex("Abilitare per usare altri utenti",$pag).".</small><br>
 <input type=\"hidden\" name=\"modifica_utenti\" value=\"1\">
