@@ -53,8 +53,8 @@ $tablepersonalizza = $PHPR_TAB_PRE."personalizza";
 
 #@include("./includes/costanti.php");
 #@include(C_DATI_PATH."/costanti.php");
-define('C_PHPR_VERSIONE_NUM',2.22);
-define('C_PHPR_VERSIONE_TXT',"2.2.2");
+define('C_PHPR_VERSIONE_NUM',2.23);
+define('C_PHPR_VERSIONE_TXT',"2.2.3");
 
 if (!function_exists('utf8_encode')) {
 function utf8_encode ($testo) { return ($testo); }
@@ -62,7 +62,8 @@ function utf8_decode ($testo) { return ($testo); }
 } # fine if (!function_exists('utf8_encode'))
 
 # Se non si specifica nessun anno uso l'attuale
-@include_once(C_DATI_PATH."/versione.php");
+if (@is_file(C_DATI_PATH."/versione.php")) include_once(C_DATI_PATH."/versione.php");
+elseif (!defined('C_DIFF_ORE')) define('C_DIFF_ORE',0);
 $anno_corrente = date("Y",(time() + (C_DIFF_ORE * 3600)));
 if (!$anno) {
 if ($id_sessione) $anno = substr($id_sessione,0,4);
@@ -301,7 +302,7 @@ $parti[1] = substr($parti[1],0,2).".".substr($parti[1],2);
 $parti[1] = round($parti[1]);
 } # fine if (strlen($parti[1]) > 2)
 $num = $parti[0].".".$parti[1];
-settype ($num,double);
+settype ($num,'double');
 } # fine if ($parti[1])
 else $num = $parti[0];
 } # fine if (count($parti) == 2)
@@ -583,7 +584,7 @@ next($_GET);
 else $action = "inizio.php";
 } # fine else if ($pag == "aggiorna.php")
 $pag = "login";
-if (C_NASCONDI_MARCA == "SI") $titolo = "Login";
+if (defined('C_NASCONDI_MARCA') and C_NASCONDI_MARCA == "SI") $titolo = "Login";
 else $titolo = mex("Login per HotelDruid","funzioni.php");
 $show_bar = "NO";
 $tema_corr = $tema[1];
@@ -612,11 +613,11 @@ if (defined("C_HTML_POST_LOGIN") and C_HTML_POST_LOGIN != "") echo C_HTML_POST_L
 if ($messaggio_errore or $mostra_form_login == "SI") {
 
 # You are not authorized to remove the following copyright notice. Ask for permission info@digitaldruid.net
-if (C_MOSTRA_COPYRIGHT != "NO") {
+if (!defined('C_MOSTRA_COPYRIGHT') or C_MOSTRA_COPYRIGHT != "NO") {
 echo "<div style=\"position: absolute; bottom: 3%; right: 1%; background: #ffffff; color: #000000; font-size: 11px;\">
 &nbsp;Website <a style=\"color: #000000;\" href=\"./mostra_sorgente.php\">engine code</a> is copyright © by DigitalDruid.Net.
 <a style=\"color: #000000;\" href=\"http://www.hoteldruid.com\">HotelDruid</a> is a free software released under the GNU/AGPL.</div>";
-} # fine if (C_MOSTRA_COPYRIGHT != "NO")
+} # fine if (!defined('C_MOSTRA_COPYRIGHT') or C_MOSTRA_COPYRIGHT != "NO")
 echo "<div>";
 
 if ($tema[1] and $tema[1] != "base" and @is_dir("./themes/".$tema[1]."/php")) include("./themes/".$tema[1]."/php/foot.php");
@@ -629,7 +630,7 @@ if ($id_utente and ($lingua[$id_utente] == "ita" or @is_dir("./includes/lang/".$
 
 if ($id_utente and $tema[$id_utente] != "base" and (!$tema[$id_utente] or !@is_dir("./themes/".$tema[$id_utente]."/php"))) $tema[$id_utente] = "base";
 
-if (C_VERSIONE_ATTUALE < C_PHPR_VERSIONE_NUM and $id_utente and $pag != "aggiorna.php") {
+if (defined('C_VERSIONE_ATTUALE') and C_VERSIONE_ATTUALE < C_PHPR_VERSIONE_NUM and $id_utente and $pag != "aggiorna.php") {
 if (@is_file(C_DATI_PATH."/dati_connessione.php") or @is_file("./dati/connessione_db.php") or @is_file("./datipermanenti/connessione_db.inc")) {
 if ($pag == "interconnessioni.php" and $id_utente != 1) {
 $id_utente_az = esegui_query("select idlocale from $PHPR_TAB_PRE"."interconnessioni where tipoid = 'id_utente_az' ");
@@ -654,7 +655,7 @@ else include("./includes/foot.php");
 } # fine else if ($id_utente == $id_utente_azione_ic) 
 unset($id_utente);
 } # fine if (@is_file(C_DATI_PATH."/dati_connessione.php") or...
-} # fine if (C_VERSIONE_ATTUALE < C_PHPR_VERSIONE_NUM and...
+} # fine if (defined('C_VERSIONE_ATTUALE') and C_VERSIONE_ATTUALE < C_PHPR_VERSIONE_NUM and...
 
 
 return $id_utente;
@@ -788,7 +789,7 @@ return $dati_transazione;
 
 
 # Function che calcola l'id del periodo corrente per le prenotazioni già iniziate ==> fisse
-function calcola_id_periodo_corrente ($anno,$anticipare="SI") {
+function calcola_id_periodo_corrente ($anno,$anticipare="SI",$data_oggi="") {
 
 global $id_utente;
 global $PHPR_TAB_PRE;
@@ -801,7 +802,8 @@ $ore_anticipa_periodo_corrente = esegui_query("select valpersonalizza_num from $
 $ore_anticipa_periodo_corrente = risul_query($ore_anticipa_periodo_corrente,0,'valpersonalizza_num');
 } # fine if ($anticipare == "SI")
 else $ore_anticipa_periodo_corrente = 0;
-$oggi = date("Y-m-d",(time() + ($ore_anticipa_periodo_corrente * 3600) + (C_DIFF_ORE * 3600)));
+if ($data_oggi) $oggi = aggslashdb($data_oggi);
+else $oggi = date("Y-m-d",(time() + ($ore_anticipa_periodo_corrente * 3600) + (C_DIFF_ORE * 3600)));
 $idperiodocorrente = esegui_query("select idperiodi from $tableperiodi where datainizio <= '$oggi' and datafine >= '$oggi' ");
 $numidperiodocorrente = numlin_query($idperiodocorrente);
 if ($numidperiodocorrente >= 1) {
