@@ -53,10 +53,10 @@ flock($filelock,2);
 $anno_esistente = esegui_query("select * from $tableanni where idanni = $anno");
 if (numlin_query($anno_esistente) == 0) {
 
-if (C_CAMBIA_TIPO_PERIODI == "NO") {
+if (defined('C_CAMBIA_TIPO_PERIODI') and C_CAMBIA_TIPO_PERIODI == "NO") {
 $tipo_periodi_esistenti = esegui_query("select * from $tableanni order by idanni desc");
 if (numlin_query($tipo_periodi_esistenti) != 0) $tipo_periodi = risul_query($tipo_periodi_esistenti,0,'tipo_periodi');
-} # fine if (C_CAMBIA_TIPO_PERIODI == "NO")
+} # fine if (defined('C_CAMBIA_TIPO_PERIODI') and C_CAMBIA_TIPO_PERIODI == "NO")
 if ($tipo_periodi != "g") $tipo_periodi = "s";
 
 // creo la tabella con periodi settimanali e prezzi e la tabella con i nomi delle tariffe
@@ -284,6 +284,11 @@ $date_option .= "<option value=\\\"$datafine2\\\">$nome_mese $numero_giorno, $nu
 ";
 fwrite($fileaperto,"<?php 
 
+\$y_ini_menu = array();
+\$m_ini_menu = array();
+\$d_ini_menu = array();
+\$n_dates_menu = array();
+\$d_increment = array();
 \$y_ini_menu[0] = \"$a_ini_menu\";
 \$m_ini_menu[0] = \"$m_ini_menu\";
 \$d_ini_menu[0] = \"$g_ini_menu\";
@@ -654,9 +659,9 @@ else $cassa_prec[$utente_costo][$nome_cassa] = $cassa_prec[$utente_costo][$nome_
 } # fine for $num1
 $datainserimento = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 reset($cassa_prec);
-while (list($utente_costo,$casse) = each($cassa_prec)) {
+foreach ($cassa_prec as $utente_costo => $casse) {
 reset($casse);
-while (list($nome_cassa,$val_costo) = each($casse)) {
+foreach ($casse as $nome_cassa => $val_costo) {
 $idcosti_corr++;
 $nome_utente = esegui_query("select * from $tableutenti where idutenti = '$utente_costo' ");
 if (numlin_query($nome_utente)) $nome_utente = risul_query($nome_utente,0,'nome_utente');
@@ -668,8 +673,8 @@ $val_costo = (double) $val_costo * -1;
 } # fine if ($val_costo < 0)
 esegui_query("insert into $tablecosti (idcosti,nome_costo,val_costo,persona_costo,tipo_costo,datainserimento,hostinserimento,utente_inserimento) values ('$idcosti_corr','$anno_prec','$val_costo','".aggslashdb($nome_utente)."','$tipo_costo','$datainserimento','$HOSTNAME','$utente_costo') ");
 if ($nome_cassa != "@#principale#@") esegui_query("update $tablecosti set nome_cassa = '".aggslashdb($nome_cassa)."' where idcosti = '$idcosti_corr' ");
-} # fine while (list($nome_cassa,$val_costo) = each($casse))
-} # fine while (list($utente_costo,$casse) = each($cassa_prec))
+} # fine foreach ($casse as $nome_cassa => $val_costo)
+} # fine foreach ($cassa_prec as $utente_costo => $casse)
 
 $colonne = "idntariffe,nomecostoagg,tipo_ca,valore_ca,valore_perc_ca,arrotonda_ca,tasseperc_ca,associasett_ca,numsett_ca,moltiplica_ca,periodipermessi_ca,beniinv_ca,appincompatibili_ca,variazione_ca,mostra_ca,categoria_ca,letto_ca,numlimite_ca,regoleassegna_ca,utente_inserimento";
 for ($num1 = 1 ; $num1 <= $num_tariffe_tab ; $num1++) {
@@ -745,7 +750,20 @@ esegui_query("update $tablenometariffe set nomecostoagg = '8' where idntariffe =
 esegui_query("update $tablenometariffe set numlimite_ca = '11' where idntariffe = '1'");
 } # fine if ($inserisci_in_ntariffe != "NO")
 
-esegui_query("delete from $tablerelclienti where tipo = 'cc' $lista_clienti_importati");
+if ((!defined('C_URL_MOD_EXT_CARTE_CREDITO') or C_URL_MOD_EXT_CARTE_CREDITO == "") and $importa_anno_prec == "SI") {
+$lista_clienti_conserva_cc = $lista_clienti_importati;
+$ini_ultimo_quad =  esegui_query("select * from $tableperiodi_prec where datainizio = '$anno_prec-09-01'");
+if (numlin_query($ini_ultimo_quad)) {
+$ini_ultimo_quad = risul_query($ini_ultimo_quad,0,'idperiodi');
+$prenota_ultimo_quad = esegui_query("select * from $tableprenota_prec where iddatafine > $ini_ultimo_quad ");
+$num_prenota_ultimo_quad = numlin_query($prenota_ultimo_quad);
+for ($num1 = 0 ; $num1 < $num_prenota_ultimo_quad ; $num1++) {
+$idclienti = risul_query($prenota_ultimo_quad,$num1,'idclienti');
+$lista_clienti_conserva_cc .= "and idclienti != '$idclienti' ";
+} # fine for $num1
+} # fine if (numlin_query($ini_ultimo_quad))
+esegui_query("delete from $tablerelclienti where tipo = 'cc' $lista_clienti_conserva_cc");
+} # fine if ((!defined('C_URL_MOD_EXT_CARTE_CREDITO') or C_URL_MOD_EXT_CARTE_CREDITO == "") and $importa_anno_prec == "SI")
 
 unlock_tabelle($tabelle_lock);
 
