@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -112,6 +112,8 @@ $dati_ca[$num1]['periodipermessi'] = substr($dati_ca[$num1]['periodipermessi_ori
 if ($dati_ca[$num1]['periodipermessi']) {
 $sett_periodipermessi = explode(",",substr($dati_ca[$num1]['periodipermessi_orig'],1));
 $num_sett_periodipermessi = count($sett_periodipermessi);
+$dati_ca[$num1]['sett_periodipermessi_ini'] = array();
+$dati_ca[$num1]['sett_periodipermessi_fine'] = array();
 for ($num2 = 0 ; $num2 < $num_sett_periodipermessi ; $num2++) {
 $sett_periodipermesso = explode("-",$sett_periodipermessi[$num2]);
 $dati_ca[$num1]['sett_periodipermessi_ini'][$num2] = $sett_periodipermesso[0];
@@ -345,6 +347,7 @@ return $settimane_costo;
 function calcola_moltiplica_costo ($dati_ca,$num_costo,&$moltiplica,$idinizioperiodo,$idfineperiodo,$settimane_costo,$nummoltiplica_ca,$numpersone,$num_letti_agg) {
 
 $moltiplica = "";
+if (!strcmp($numpersone,"")) $numpersone = 0;
 if (!$dati_ca[$num_costo]['molt_agg']) $dati_ca[$num_costo]['molt_agg'] = 0;
 if ($dati_ca[$num_costo]['moltiplica'] == "1") $moltiplica = 1;
 if ($dati_ca[$num_costo]['moltiplica'] == "c") $moltiplica = $nummoltiplica_ca;
@@ -594,9 +597,10 @@ if ($dati_ca[$num_costo]['tipo'] == "u") $num_ripetizioni_costo = 1;
 if ($dati_ca[$num_costo]['tipo'] == "s") {
 if ($dati_ca[$num_costo]['associasett'] == "s") {
 $num_sett = 1;
+$moltiplica_sett = explode(",",$moltiplica);
 for ($num1 = $idinizioperiodo ; $num1 <= $idfineperiodo ; $num1++) {
 if (str_replace(",".$num1.",","",$settimane_costo) != $settimane_costo) {
-$num_ripetizioni_costo = $num_ripetizioni_costo + $moltiplica[$num_sett];
+$num_ripetizioni_costo = $num_ripetizioni_costo + $moltiplica_sett[$num_sett];
 $num_sett++;
 } # fine if (str_replace(",".$num1.",","",$settimane_costo) != $settimane_costo)
 } # fine for $num1
@@ -657,43 +661,51 @@ return $beni_presenti;
 function aggiorna_beniinv_presenti ($tablerelinventario,$beniinv_presenti) {
 
 if ($beniinv_presenti) {
-while (list($tipo_beniinv,$val) = each($beniinv_presenti)) {
+foreach ($beniinv_presenti as $tipo_beniinv => $val) {
 $idmag = substr($tipo_beniinv,3);
 $tipo_beneinv = substr($tipo_beniinv,0,3);
 if ($tipo_beneinv == "mag") $cond_mag = "idmagazzino = '$idmag'";
 else $cond_mag = "idappartamento = '".aggslashdb($idmag)."'";
 $id_beniinv = $val;
-while (list($id_beneinv,$n_num_bene) = each($id_beniinv)) {
+foreach ($id_beniinv as $id_beneinv => $n_num_bene) {
 esegui_query("update $tablerelinventario set quantita = '$n_num_bene' where idbeneinventario = '$id_beneinv' and $cond_mag ");
-} # fine while (list($id_beneinv,$n_num_bene) = each($id_beniinv))
-} # fine while (list($tipo_beniinv,$val) = each($beniinv_presenti))
+} # fine foreach ($id_beniinv as $id_beneinv => $n_num_bene)
+} # fine foreach ($beniinv_presenti as $tipo_beniinv => $val)
 } # fine if ($beniinv_presenti)
 
 } # fine function aggiorna_beniinv_presenti
 
 
 
-function aggiorna_privilegi_ins_costo ($idntariffe,$tableprivilegi,$id_utente,$anno,$attiva_costi_agg_consentiti,$priv_ins_costi_agg,$utenti_gruppi) {
+function aggiorna_privilegi_ins_costo ($idntariffe,$tableprivilegi,$id_utente,$anno,$attiva_costi_agg_consentiti,$priv_ins_costi_agg,$utenti_gruppi,$q_utenti_costi_sel="") {
 
 if ($attiva_costi_agg_consentiti != "n") {
-$costi_agg_cons_int = esegui_query("select costi_agg_consentiti from $tableprivilegi where idutente = '$id_utente'  and anno = '$anno' ");
+$costi_agg_cons_int = esegui_query("select costi_agg_consentiti from $tableprivilegi where idutente = '$id_utente' and anno = '$anno' ");
 $costi_agg_cons_int = risul_query($costi_agg_cons_int,0,"costi_agg_consentiti");
-esegui_query("update $tableprivilegi set costi_agg_consentiti = '$costi_agg_cons_int,$idntariffe' where idutente = '$id_utente'  and anno = '$anno' ");
+esegui_query("update $tableprivilegi set costi_agg_consentiti = '$costi_agg_cons_int,$idntariffe' where idutente = '$id_utente' and anno = '$anno' ");
 } # fine if ($attiva_costi_agg_consentiti != "n")
-if ($priv_ins_costi_agg == "g") {
+if ($priv_ins_costi_agg == "g" or ($id_utente == 1 and $q_utenti_costi_sel)) {
+if ($id_utente == 1 and !@is_array($utenti_gruppi)) {
+if ($q_utenti_costi_sel == "q") {
+global $LIKE;
+$q_utenti_costi_sel = esegui_query("select * from $tableprivilegi where anno = '$anno' and costi_agg_consentiti $LIKE 's%' ");
+} # fine if ($q_utenti_costi_sel == "q")
+$utenti_gruppi = array();
+for ($num1 = 0 ; $num1 < numlin_query($q_utenti_costi_sel) ; $num1++) $utenti_gruppi[risul_query($q_utenti_costi_sel,$num1,'idutente')] = 1;
+} # fine if ($id_utente == 1 and !@is_array($utenti_gruppi))
 reset($utenti_gruppi);
-while (list($idut_gr,$val) = each($utenti_gruppi)) {
+foreach ($utenti_gruppi as $idut_gr => $val) {
 if ($idut_gr != $id_utente) {
-$costi_agg_cons_int = esegui_query("select costi_agg_consentiti from $tableprivilegi where idutente = '$idut_gr'  and anno = '$anno' ");
+$costi_agg_cons_int = esegui_query("select costi_agg_consentiti from $tableprivilegi where idutente = '$idut_gr' and anno = '$anno' ");
 if (numlin_query($costi_agg_cons_int) == 1) {
 $costi_agg_cons_int = risul_query($costi_agg_cons_int,0,'costi_agg_consentiti');
 if (substr($costi_agg_cons_int,0,1) != "n") {
-esegui_query("update $tableprivilegi set costi_agg_consentiti = '$costi_agg_cons_int,$idntariffe' where idutente = '$idut_gr'  and anno = '$anno' ");
+esegui_query("update $tableprivilegi set costi_agg_consentiti = '$costi_agg_cons_int,$idntariffe' where idutente = '$idut_gr' and anno = '$anno' ");
 } # fine if (substr($costi_agg_cons_int,0,1) != "n")
 } # fine if (numlin_query($costi_agg_cons_int) == 1)
 } # fine if ($idut_gr != $id_utente)
-} # fine while (list($idut_gr,$val) = each($utenti_gruppi))
-} # fine if ($priv_ins_costi_agg == "g")
+} # fine foreach ($utenti_gruppi as $idut_gr => $val)
+} # fine if ($priv_ins_costi_agg == "g" or ($id_utente == 1 and $q_utenti_costi_sel))
 
 } # fine function aggiorna_privilegi_ins_costo
 
