@@ -148,7 +148,7 @@ if (numlin_query($cliente_esistente) != 1) $inserire = "NO";
 else $cognome = risul_query($cliente_esistente,0,"cognome");
 } # fine else if (controlla_num_pos($idclienti[$n_t]) == "NO")
 
-$app_richiesti_id[$n_t] = "";
+$app_richiesti_id[$n_t] = array();
 $assegnazioneapp[$n_t] = "v";
 if ($lista_app[$n_t]) {
 $assegnazioneapp[$n_t] = "c";
@@ -186,7 +186,7 @@ $lista_app[$n_t] = substr($lista_app[$n_t],1);
 $app_eliminati_costi[$n_t] = substr($app_eliminati_costi[$n_t],1);
 if (str_replace(",","",$lista_app[$n_t]) != $lista_app[$n_t]) $assegnazioneapp[$n_t] = "c";
 else $assegnazioneapp[$n_t] = "k";
-$app_richiesti_id[$n_t] = "";
+$app_richiesti_id[$n_t] = array();
 $vett_app = explode(",",$lista_app[$n_t]);
 $num_app = count($vett_app);
 for ($num1 = 0 ; $num1 < $num_app ; $num1++) $app_richiesti_id[$n_t][$vett_app[$num1]] = "SI";
@@ -240,7 +240,7 @@ $inserire = "NO";
 
 unset($lista_app_richiesti);
 if (!$app_richiesti_id[$n_t]) $lista_app_richiesti = ",tutti,,";
-else while (list($key, $val) = each($app_richiesti_id[$n_t])) if ($val == "SI") $lista_app_richiesti .= $key.",";
+else foreach ($app_richiesti_id[$n_t] as $key => $val) if ($val == "SI") $lista_app_richiesti .= $key.",";
 $lista_app_richiesti = substr($lista_app_richiesti,0,-1);
 $id_app_richiesti++;
 $app_richiesti[$id_app_richiesti] = $lista_app_richiesti;
