@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -224,7 +224,7 @@ $tablesoldi = $PHPR_TAB_PRE."soldi".$anno;
 
 $id_prenota = aggslashdb($id_prenota);
 $id_prenota_int = $id_prenota;
-$id_prenota_idpr = "";
+$id_prenota_idpr = array();
 $id_prenota_idpr[0] = $id_prenota;
 $num_id_prenota = 1;
 if (str_replace(",","",$id_prenota) != $id_prenota) {
@@ -286,33 +286,33 @@ $tableappartamenti = $PHPR_TAB_PRE."appartamenti";
 $tableclienti = $PHPR_TAB_PRE."clienti";
 $tablecostiprenota = $PHPR_TAB_PRE."costiprenota".$anno;
 
-$d_id_utente_inserimento_idpr = "";
-$d_id_clienti_idpr = "";
-$d_id_data_inizio_idpr = "";
-$d_id_data_fine_idpr = "";
-$d_appartamento_idpr = "";
-$d_assegnazione_app_idpr = "";
-$d_app_assegnabili_idpr = "";
-$d_nome_tipotariffa_idpr = "";
-$d_costo_tariffa_idpr = "";
-$d_molt_tariffa_idpr = "";
-$d_app_eliminati_costi_idpr = "";
-$d_sconto_idpr = "";
-$d_caparra_idpr = "";
-$d_met_paga_caparra_idpr = "";
-$d_commissioni_idpr = "";
-$d_num_persone_idpr = "";
-$d_nome_tariffa_idpr = "";
-$d_tariffesettimanali_idpr = "";
-$d_costo_agg_tot_idpr = "";
-$d_prezzo_costo_agg_idpr = "";
-$d_costo_tot_idpr = "";
-$d_pagato_idpr = "";
-$d_confermato_idpr = "";
-$d_checkin_idpr = "";
-$d_checkout_idpr = "";
-$d_prenota_comp_idpr = "";
-$n_host_inserimento_idpr = "";
+$d_id_utente_inserimento_idpr = array();
+$d_id_clienti_idpr = array();
+$d_id_data_inizio_idpr = array();
+$d_id_data_fine_idpr = array();
+$d_appartamento_idpr = array();
+$d_assegnazione_app_idpr = array();
+$d_app_assegnabili_idpr = array();
+$d_nome_tipotariffa_idpr = array();
+$d_costo_tariffa_idpr = array();
+$d_molt_tariffa_idpr = array();
+$d_app_eliminati_costi_idpr = array();
+$d_sconto_idpr = array();
+$d_caparra_idpr = array();
+$d_met_paga_caparra_idpr = array();
+$d_commissioni_idpr = array();
+$d_num_persone_idpr = array();
+$d_nome_tariffa_idpr = array();
+$d_tariffesettimanali_idpr = array();
+$d_costo_agg_tot_idpr = array();
+$d_prezzo_costo_agg_idpr = array();
+$d_costo_tot_idpr = array();
+$d_pagato_idpr = array();
+$d_confermato_idpr = array();
+$d_checkin_idpr = array();
+$d_checkout_idpr = array();
+$d_prenota_comp_idpr = array();
+$n_host_inserimento_idpr = array();
 
 $dati_tariffe = dati_tariffe($tablenometariffe,"","",$tableregole);
 $dati_ca = dati_costi_agg_ntariffe($tablenometariffe,$dati_tariffe['num'],"NO","",$tableappartamenti);
@@ -500,7 +500,7 @@ $n_host_inserimento_idpr[$id_prenota] = risul_query($dati_prenota_modifica,0,'ho
 function esegui_modifiche_prenotazione (&$inserire,&$cancellata,$id_prenota_int,$id_prenota_idpr,$num_id_prenota,$id_transazione,$id_sessione,$anno,$id_nuovo_utente_inserimento,$n_stima_checkin,$n_met_paga_caparra,$n_origine_prenota,$n_pagato,$n_confermato,$tipo_commento,$n_commento,$n_cancella_commento,$tableprenota_da_aggiornare,$tipo_sposta,$dati_da_anno_prec,$prenota_in_anno_succ,$tra_anni,$PHPR_TAB_PRE) {
 global $id_utente,$priv_mod_checkin,$attiva_regole1_consentite,$regole1_consentite,$attiva_tariffe_consentite,$tariffe_consentite_vett,$priv_mod_date,$priv_ins_periodi_passati,$priv_mod_commento,$priv_mod_commenti_pers,$priv_mod_sconto,$priv_mod_caparra,$priv_mod_pagato,$priv_mod_orig_prenota,$d_commento,$cassa_pagamenti,$nome_utente;
 global $dati_ca,$d_id_utente_inserimento_idpr,$d_appartamento_idpr,$d_id_data_inizio_idpr,$d_nome_tariffa_idpr,$d_app_eliminati_costi_idpr,$d_checkin_idpr,$d_checkout_idpr,$d_prenota_comp_idpr,$fineperiodo_orig,$comm_pers_presenti;
-global $id_prenota_orig,$tableperiodi_orig,$tableprenota_orig,$tablecostiprenota_orig,$tableperiodi_prec,$tableprenota_prec,$tablecostiprenota_prec,$stile_data;
+global $id_prenota_orig,$tableperiodi_orig,$tableprenota_orig,$tablecostiprenota_orig,$tableperiodi_prec,$tableprenota_prec,$tablecostiprenota_prec,$stile_data,$tipo_n_app;
 
 $pag = "modifica_prenota.php";
 $tablenometariffe = $PHPR_TAB_PRE."ntariffe".$anno;
@@ -669,13 +669,24 @@ $cancellata = "SI";
 $inizioperiodo = "";
 $fineperiodo = "";
 } # fine if ($n_data_inserimento != $d_data_inserimento_idpr[$num_idpr] or ...
-if ($n_appartamento != "") $appartamento = $n_appartamento;
+if (strcmp($n_appartamento,"")) $appartamento = $n_appartamento;
 else $appartamento = risul_query($dati_prenota_idpr[$id_prenota],0,'idappartamenti');
 if ($n_numpersone != "") $numpersone = $n_numpersone;
 else $numpersone = risul_query($dati_prenota_idpr[$id_prenota],0,'num_persone');
 if (!$numpersone) $numpersone = 0;
 if ($n_assegnazioneapp != "") $assegnazioneapp = $n_assegnazioneapp;
 else $assegnazioneapp = risul_query($dati_prenota_idpr[$id_prenota],0,'assegnazioneapp');
+if ($tipo_n_app == "aggiungi" and strcmp($n_appartamento,"") and $assegnazioneapp == "k") {
+$n_assegnazioneapp = "c";
+$assegnazioneapp = "c";
+$n_lista_app = risul_query($dati_prenota_idpr[$id_prenota],0,'app_assegnabili');
+if (!strstr(",$n_lista_app,",",$n_appartamento,")) {
+if (!strcmp($n_lista_app,"")) $n_lista_app = risul_query($dati_prenota_idpr[$id_prenota],0,'idappartamenti');
+$n_lista_app .= ",$n_appartamento";
+} # fine if (!strstr(",$n_lista_app,",",$n_appartamento,"))
+$n_assegnazioneapp_idpr[$id_prenota] = $n_assegnazioneapp;
+$n_lista_app_idpr[$id_prenota] = $n_lista_app;
+} # fine if ($tipo_n_app == "aggiungi" and strcmp($n_appartamento,"" and $n_assegnazioneapp == "k")
 if ($n_lista_app != "") $lista_app = $n_lista_app;
 else $lista_app = risul_query($dati_prenota_idpr[$id_prenota],0,'app_assegnabili');
 if ($n_inizioperiodo != "") $inizioperiodo = $n_inizioperiodo;
