@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2014 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -33,6 +33,7 @@ $MEDIUMTEXT = "mediumtext";
 unset($link_mysqli);
 
 
+
 function connetti_db ($database,$host,$port,$user,$password,$estensione) {
 
 global $link_mysqli;
@@ -45,6 +46,7 @@ return $link_mysqli;
 } # fine function connetti_db
 
 
+
 function disconnetti_db (&$numconnessione) {
 
 $risul = mysqli_close($numconnessione);
@@ -53,6 +55,7 @@ return $risul;
 } # fine function disconnetti_db
 
 
+
 if (substr($PHPR_LOG,0,2) != "SI") {
 
 function esegui_query ($query,$silenzio = "",$idlog = "") {
@@ -94,6 +97,7 @@ return $risul;
 } # fine else if (substr($PHPR_LOG,0,2) != "SI")
 
 
+
 function risul_query (&$query,$riga,$colonna,$tab="") {
 
 /*
@@ -120,6 +124,7 @@ return $query[1][$colonna];
 } # fine function risul_query
 
 
+
 function numlin_query ($query) {
 
 $risul = mysqli_num_rows($query[-1]);
@@ -136,6 +141,7 @@ return $risul;
 } # fine function aggslashdb
 
 
+
 function arraylin_query (&$query,$num) {
 
 if ($query[-2] != ($num - 1)) mysqli_data_seek($query[-1],$num);
@@ -146,6 +152,7 @@ return $risul;
 } # fine function arraylin_query
 
 
+
 function numcampi_query ($query) {
 
 $risul = mysqli_num_fields($query[-1]);
@@ -154,6 +161,7 @@ return $risul;
 } # fine function numcampi_query
 
 
+
 function nomecampo_query ($query,$num) {
 
 $risul = mysqli_fetch_field_direct($query[-1],$num);
@@ -162,6 +170,7 @@ return $risul->name;
 } # fine function nomecampo_query
 
 
+
 function tipocampo_query ($query,$num) {
 
 $risul = mysqli_fetch_field_direct($query[-1],$num);
@@ -170,6 +179,7 @@ return $risul->type;
 } # fine function tipocampo_query
 
 
+
 function dimcampo_query ($query,$num) {
 
 $risul = mysqli_fetch_field_direct($query[-1],$num);
@@ -178,7 +188,17 @@ return $risul->max_length;
 } # fine function dimcampo_query
 
 
-function lock_tabelle ($tabelle,$altre_tab_usate = "",$lock_dir = C_DATI_PATH) {
+
+function chiudi_query (&$query) {
+
+mysqli_free_result($query[-1]);
+$query = array();
+
+} # fine function chiudi_query
+
+
+
+function lock_tabelle ($tabelle,$altre_tab_usate = "") {
 
 if (@is_array($tabelle)) {
 for ($num1 = 0 ; $num1 < count($tabelle); $num1++) {
@@ -208,6 +228,7 @@ $risul = mysqli_query($link_mysqli,"unlock tables");
 } # fine function unlock_tabelle
 
 
+
 function crea_indice ($tabella,$colonne,$nome) {
 
 global $link_mysqli;
