@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2012 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -32,6 +32,7 @@ $DATETIME = "timestamp";
 $MEDIUMTEXT = "text";
 
 
+
 function connetti_db ($database,$host,$port,$user,$password,$estensione) {
 
 if ($estensione == "SI") dl("pgsql.so");
@@ -43,6 +44,7 @@ return $numconnessione;
 } # fine function connetti_db
 
 
+
 function disconnetti_db ($numconnessione) {
 
 $risul = pg_close($numconnessione);
@@ -51,6 +53,7 @@ return $risul;
 } # fine function disconnetti_db
 
 
+
 if (substr($PHPR_LOG,0,2) != "SI") {
 
 function esegui_query ($query,$silenzio = "",$idlog = "") {
@@ -87,6 +90,7 @@ return $risul;
 } # fine else if (substr($PHPR_LOG,0,2) != "SI")
 
 
+
 function risul_query ($query,$riga,$colonna,$tab="") {
 
 $risul = pg_result($query,$riga,$colonna);
@@ -95,6 +99,7 @@ return $risul;
 } # fine function risul_query
 
 
+
 function numlin_query ($query) {
 
 $risul = pg_numrows($query);
@@ -103,6 +108,7 @@ return $risul;
 } # fine function numlin_query
 
 
+
 if (function_exists('pg_escape_string')) {
 function aggslashdb ($stringa) {
 
@@ -122,6 +128,7 @@ return $risul;
 } # fine else if (function_exists('pg_escape_string'))
 
 
+
 function arraylin_query ($query,$num) {
 
 $risul = pg_fetch_row($query,$num);
@@ -130,6 +137,7 @@ return $risul;
 } # fine function arraylin_query
 
 
+
 function numcampi_query ($query) {
 
 $risul = pg_numfields($query);
@@ -138,6 +146,7 @@ return $risul;
 } # fine function numcampi_query
 
 
+
 function nomecampo_query ($query,$num) {
 
 $risul = pg_fieldname($query,$num);
@@ -146,6 +155,7 @@ return $risul;
 } # fine function nomecampo_query
 
 
+
 function tipocampo_query ($query,$num) {
 
 $risul = pg_fieldtype($query,$num);
@@ -154,6 +164,7 @@ return $risul;
 } # fine function tipocampo_query
 
 
+
 function dimcampo_query ($query,$num) {
 
 $risul = pg_fieldsize($query,$num);
@@ -162,6 +173,16 @@ return $risul;
 } # fine function dimcampo_query
 
 
+
+function chiudi_query (&$query) {
+
+pg_free_result($query);
+$query = "";
+
+} # fine function chiudi_query
+
+
+
 function lock_tabelle ($tabelle,$altre_tab_usate = "") {
 
 if (@is_array($tabelle)) {
@@ -180,6 +201,7 @@ return $risul;
 } # fine function lock_tabelle
 
 
+
 function unlock_tabelle ($tabelle_lock,$azione = "") {
 
 if ($tabelle_lock != "nocommit") {
@@ -190,6 +212,7 @@ else pg_exec("commit");
 } # fine function unlock_tabelle
 
 
+
 function crea_indice ($tabella,$colonne,$nome) {
 
 pg_exec("create index $nome on $tabella ($colonne)");
