@@ -109,6 +109,7 @@ return $dati_tariffe;
 function dati_regole2 (&$dati_r2,&$app_regola2_predef,$tipotariffa,$idinizioperiodo,$idfineperiodo,&$id_periodo_corrente,$tipo_periodi,$anno,$tableregole) {
 
 if (!is_array($dati_r2)) {
+$dati_r2 = array();
 $regole2 = esegui_query("select * from $tableregole where tariffa_per_app != ''");
 $dati_r2['num'] = numlin_query($regole2);
 
@@ -175,7 +176,7 @@ $commissioni_percent = $dati_tariffe[$tipotariffa]['commissioni_percent']['def']
 $commissioni_arrotond = $dati_tariffe[$tipotariffa]['commissioni_arrotond']['def'];
 $commissioni_base = $dati_tariffe[$tipotariffa]['commissioni_base']['def'];
 reset($dati_tariffe[$tipotariffa]['commissioni_percent']);
-while (list($per_comm,$val_comm) = each($dati_tariffe[$tipotariffa]['commissioni_percent'])) {
+foreach ($dati_tariffe[$tipotariffa]['commissioni_percent'] as $per_comm => $val_comm) {
 if ($per_comm != "def") {
 $ini_comm = explode("-",$per_comm);
 $fine_comm = $ini_comm[1];
@@ -187,7 +188,7 @@ $commissioni_base = $dati_tariffe[$tipotariffa]['commissioni_base'][$per_comm];
 break;
 } # fine if ($num1 >= $ini_comm and $num1 <= $fine_comm)
 } # fine if ($per_comm != "def")
-} # fine while (list($per_comm,$val_comm) = each($dati_tariffe[$tariffa]['commissioni_percent']))
+} # fine foreach ($dati_tariffe[$tipotariffa]['commissioni_percent'] as $per_comm => $val_comm)
 
 if ($num1 != $iddataini and ($ultime_comm_perc != $commissioni_percent or $ultime_comm_arr != $commissioni_arrotond or $ultime_comm_base != $commissioni_base)) {
 if ($ultime_comm_perc) {
@@ -292,7 +293,7 @@ $tariffa = "tariffa".$tar_esporta[$num_tar];
 
 if ($idperiodo == "opztariffa") {
 $tablenometariffe = $prezzoperiodop;
-$opztariffa = esegui_query("select * from $tableperiodi where $tariffa"."p is not NULL and $tariffa"."p != '' and $tariffa"."p != '0' ");
+$opztariffa = esegui_query("select * from $tableperiodi where $tariffa"."p is not NULL and $tariffa"."p != '0' ");
 if (numlin_query($opztariffa)) $opztariffa = "p";
 else $opztariffa = "s";
 esegui_query("update $tablenometariffe set $tariffa = '$opztariffa' where idntariffe = '4' ");
@@ -384,4 +385,21 @@ $num_ord_prec = $num_ord;
 
 
 
+function periodo_importato_tar ($tariffa,$idperiodo,$dati_tariffe) {
+$imp_periodo = 0;
+if ($dati_tariffe[$tariffa]['imp_prezzi_int']) {
+if ($dati_tariffe[$tariffa]['importa_prezzi'][0]) $imp_periodo = $dati_tariffe[$tariffa]['importa_prezzi'][0];
+for ($num1 = 1 ; $num1 < $dati_tariffe[$tariffa]['num_per_importa'] ; $num1++) {
+if ($dati_tariffe[$tariffa]['periodo_importa_f'][$num1] >= $idperiodo and $dati_tariffe[$tariffa]['periodo_importa_i'][$num1] <= $idperiodo) {
+$imp_periodo = $dati_tariffe[$tariffa]['importa_prezzi'][$num1];
+break;
+} # fine if ($dati_tariffe[$tariffa]['periodo_importa_f'][$num1] >= $idinizioperiodo and...
+} # fine for $num1
+} # fine if ($dati_tariffe[$tariffa]['imp_prezzi_int'])
+return $imp_periodo;
+} # fine function periodo_importato_tar
+
+
+
+
 ?>
\ No newline at end of file
