@@ -403,6 +403,10 @@ case "La tariffa":  				$messaggio = "Rate"; break;
 case "è ancora in uso nelle interconnessioni":	$messaggio = "is still in use in interconnections"; break;
 case "almeno 8 caratteri, con lettere e numeri o simboli":	$messaggio = "at least 8 characters, with letters and numbers or symbols"; break;
 case "diversa dalle ultime":  			$messaggio = "different from last"; break;
+case "Condizioni Generali di Contratto":  	$messaggio = "General Terms and Conditions"; break;
+case "del servizio di memorizzazione delle carte di credito":	$messaggio = "of the credit cards storage service"; break;
+case "La password non è stata modificata":  	$messaggio = "The password has not been modified"; break;
+case "password errata":  			$messaggio = "wrong password"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
