@@ -349,6 +349,9 @@ case "potrà modificare i <b>documenti come API</b>":	$messaggio = "will be able
 case "Attenzione":  				$messaggio = "Warning"; break;
 case "questo può consentire l'accesso ai dati di tutte le prenotazioni":	$messaggio = "this can allow access to data of all reservations"; break;
 case "non potrà più modificare i <b>documenti come API</b>":	$messaggio = "will not be able to modify <b>documents as API</b> anymore"; break;
+case "Gestione della password per le carte di credito":	$messaggio = "Management of credit cards password"; break;
+case "potrà gestire la <b>password per le carte di credito</b>":	$messaggio = "will be able to manage the <b>credit cards password</b>"; break;
+case "non potrà più gestire la <b>password per le carte di credito</b>":	$messaggio = "will not be able to manage the <b>credit cards password</b>"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
