@@ -25,10 +25,10 @@ case "La prenotazione dal":  			$messaggio = "La reserva desde el"; break;
 case "a nome di":  				$messaggio = "a nombre de"; break;
 case "Non si può procedere perchè la tabella prenotazioni è cambiata nel frattempo":	$messaggio = "No se puede continuar porque ha cambiado la tabla de reservas mientras tanto"; break;
 case "Continua lo stesso":  			$messaggio = "Continua lo mismo"; break;
-case "Torna indietro":  			$messaggio = "Vuelve atrás"; break;
+case "Torna indietro":  			$messaggio = "Volver atrás"; break;
 case "Non esistono clienti chiamati":  		$messaggio = "No existen clientes llamados"; break;
 case "nel database":  				$messaggio = "en la base de datos"; break;
-case "Inserisci i dati di un nuovo cliente":  	$messaggio = "Inserta los datos de un nuevo cliente"; break;
+case "Inserisci i dati di un nuovo cliente":  	$messaggio = "Insertar los datos de un nuevo cliente"; break;
 case "Esistono i seguenti clienti con un cognome uguale o simile":	$messaggio = "Existen los siguientes clientes con apedillo igual o similar"; break;
 case "Esistono i seguenti clienti con un cognome e nome uguale o simile":	$messaggio = "Existen los siguientes clientes con apedillo y nombre igual o similar"; break;
 case "nato il":	  				$messaggio = "nacido el"; break;
@@ -40,11 +40,11 @@ case "3º telefono":  				$messaggio = "3º teléfono"; break;
 case "Utilizza il cliente":  			$messaggio = "Utiliza el cliente"; break;
 case "per la prenotazione":  			$messaggio = "para la reserva"; break;
 case "Modifica i dati del cliente":  		$messaggio = "Modificar los datos del cliente"; break;
-case "Inserisci un nuovo cliente":  		$messaggio = "Inserta un nuevo cliente"; break;
+case "Inserisci un nuovo cliente":  		$messaggio = "Insertar un nuevo cliente"; break;
 case "É necessario inserire il cognome del cliente":	$messaggio = "Hay que insertar el apellido del cliente"; break;
 case "I dati del cliente":  			$messaggio = "Los datos del cliente"; break;
 case "sono stati inseriti":  			$messaggio = "han sido insertados"; break;
-case "Inserisci o modifica i dati di un cliente":	$messaggio = "Inserta o modifica los datos de un cliente"; break;
+case "Inserisci o modifica i dati di un cliente":	$messaggio = "Insertar o modificar los datos de un cliente"; break;
 case "Cognome":  				$messaggio = "Apellido"; break;
 case "nome":  					$messaggio = "nombre"; break;
 case "sesso":  					$messaggio = "sexo"; break;
@@ -62,14 +62,14 @@ case "Secondo telefono":  			$messaggio = "Seguno teléfono"; break;
 case "Terzo telefono":  			$messaggio = "Tercer teléfono"; break;
 case "Numero di fax":  				$messaggio = "Número de fax"; break;
 case "Seconda persona di riferimento":  	$messaggio = "Segunda persona de referencia"; break;
-case "Inserisci i dati":  			$messaggio = "Inserta los datos"; break;
+case "Inserisci i dati":  			$messaggio = "Insertar los datos"; break;
 case "Torna al menù principale":  		$messaggio = "Volver al menú principal"; break;
 case "Italia":  				$messaggio = ""; break;
 case "non verrano modificati i dati specifici delle 2 persone di riferimento":	$messaggio = "no serán modificados los datos específicos de las 2 personas de referencia"; break;
 case "sono stati modificati":  			$messaggio = "han sido modificados"; break;
 case "e":  					$messaggio = "y"; break;
 case "Il numero di prenotazioni è sbagliato":	$messaggio = "El número de reservas está equivocado"; break;
-case "Aggiungi":  				$messaggio = "Añade"; break;
+case "Aggiungi":  				$messaggio = "Añadir"; break;
 case "Nº di tipologie da aggiungere":  		$messaggio = "Nº de tipologías a añadir"; break;
 case "Non si è trovato nessun cliente chiamato":	$messaggio = "No se ha encontrado ningún cliente llamado"; break;
 case "Non c'è nussun periodo delle regole 1 in cui sia consentito inserire prenotazioni per l'utente":	$messaggio = "No hay ningún período de las reglas 1 en el que esté consentido insertar reservas para el usuario"; break;
@@ -91,7 +91,7 @@ case "non può essere applicato":  		$messaggio = "no puede ser aplicado"; break
 case "regione":  				$messaggio = "región"; break;
 case "Documento":  				$messaggio = "Documento"; break;
 case "scadenza":  				$messaggio = "expiración"; break;
-case "Torna all'inserimento clienti":  		$messaggio = "Vuelve a la inserción de los clientes"; break;
+case "Torna all'inserimento clienti":  		$messaggio = "Volver a la inserción de los clientes"; break;
 case "Annulla":  				$messaggio = "Anular"; break;
 case "Ospite della prenotazione":  		$messaggio = "Huésped de la reserva"; break;
 case "tipologia":  				$messaggio = "tipología"; break;
