@@ -24,13 +24,13 @@ case "e/o di casa":  				$messaggio = "y/o de casa"; break;
 case "e/o di persone":  			$messaggio = "y/o de personas"; break;
 case "Nº di persone":  				$messaggio = "N° de personas"; break;
 case "Commento":  				$messaggio = "Comentario"; break;
-case "Cancella il commento":  			$messaggio = "Borra el comentario"; break;
+case "Cancella il commento":  			$messaggio = "Borrar el comentario"; break;
 case "Tipo di tariffa":  			$messaggio = "Tipo de tarifa"; break;
 case "tariffa":  				$messaggio = "tarifa"; break;
 case "Sconto":  				$messaggio = "Descuento"; break;
 case "Caparra":  				$messaggio = "Fianza"; break;
 case "resto":  					$messaggio = "resto"; break;
-case "Ricalcola la caparra in base alla nuova tariffa":	$messaggio = "Vuelve a calcular la fianza en base a la nueva tarifa"; break;
+case "Ricalcola la caparra in base alla nuova tariffa":	$messaggio = "Volver a calcular la fianza en base a la nueva tarifa"; break;
 case "Costo aggiuntivo unico":  		$messaggio = "Coste añadido único"; break;
 case "moltiplicato per":  			$messaggio = "multiplicado por"; break;
 case "Costo aggiuntivo settimanale":  		$messaggio = "Coste añadido semanal"; break;
@@ -57,11 +57,11 @@ case "nº di settimane da applicare":  		$messaggio = "n° de samanas a aplicar"
 case "nº di giorni da applicare":  		$messaggio = "n° de días a aplicar"; break;
 case "non specificato":  			$messaggio = "no especificado"; break;
 case "Modifica la prenotazione":  		$messaggio = "Modificar la reserva"; break;
-case "Cancella la prenotazione":  		$messaggio = "Borra la reserva"; break;
+case "Cancella la prenotazione":  		$messaggio = "Borrar la reserva"; break;
 case "documento di tipo":  			$messaggio = "documento tipo"; break;
 case "visualizza":  				$messaggio = "ver"; break;
 case "visualizza il documento":  		$messaggio = "ver el documento"; break;
-case "Torna indietro":  			$messaggio = "Vuelve atrás"; break;
+case "Torna indietro":  			$messaggio = "Volver atrás"; break;
 case "SI":  					$messaggio = "SI"; break;
 case "cancella anche ciò che era stato pagato":	$messaggio = "borra también lo que ya había sido pagado"; break;
 case "NO":  					$messaggio = "NO"; break;
@@ -133,7 +133,7 @@ case "verrà <b>confermata</b>":  			$messaggio = "será <b>confirmada</b>"; bre
 case "Verrà tolta la <b>conferma</b> alla prenotazione":	$messaggio = "Se quitará <b>confirmación</b>a la reserva"; break;
 case "Il <b>commento</b> verrà cambiato":  	$messaggio = "El <b>comentario</b> será cambiado"; break;
 case "Il <b>commento</b> verrà cancellato":  	$messaggio = "El <b>comentario</b> será borrado"; break;
-case "Continua":  				$messaggio = "Continua"; break;
+case "Continua":  				$messaggio = "Continuar"; break;
 case "modificata":  				$messaggio = "modificada"; break;
 case "<b>non è stata modificata</b> perchè la tabella prenotazioni è cambiata nel frattempo":	$messaggio = "<b>no ha sido modificada</b> porqué la tabla de reservas ha cambiado mientras tanto"; break;
 case "verrà cambiato da":  			$messaggio = "será cambiado de"; break;
@@ -215,7 +215,7 @@ case "Origine":  				$messaggio = "Origen"; break;
 case "L'origine della prenotazione verrà cambiata a":	$messaggio = "El origen de la reserva será cambiado a"; break;
 case "Modifica o cancella le prenotazioni":  	$messaggio = "Modificar o borrar las reservas"; break;
 case "Modifica le prenotazioni":  		$messaggio = "Modificar las reservas"; break;
-case "Cancella le prenotazioni":  		$messaggio = "Borra las reservas"; break;
+case "Cancella le prenotazioni":  		$messaggio = "Borrar las reservas"; break;
 case "della prenotazione":  			$messaggio = "de la reserva"; break;
 case "per la prenotazione":  			$messaggio = "para la reserva"; break;
 case "Data inserimento":  			$messaggio = "Fecha de inserción"; break;
@@ -228,7 +228,7 @@ case "Si deve inserire il <span class=\"colred\">numero delle persone</span> per
 case "Partita iva":  				$messaggio = "C.I.F."; break;
 case "i beni richiesti alla registrazione dell'entrata":	$messaggio = "los bienes necesarios para registrar la entrada"; break;
 case "Commissioni":  				$messaggio = "Comisiones"; break;
-case "Ricalcola le commissioni in base alla nuova tariffa":	$messaggio = "Vuelve a calcular las comisiones en base a la nueva tarifa"; break;
+case "Ricalcola le commissioni in base alla nuova tariffa":	$messaggio = "Volver a calcular las comisiones en base a la nueva tarifa"; break;
 case "Le commissioni verranno cambiate da":	$messaggio = "Las comisiones serán cambiadas desde"; break;
 case "tasse":  					$messaggio = "tasas"; break;
 case "Il prezzo totale cambierà da":  		$messaggio = "El precio total cambiará de"; break;
