@@ -294,7 +294,7 @@ case "attiva la password":  			$messaggio = "activar la contraseña"; break;
 case "le password inserite non coincidono":  	$messaggio = "las contraseñas insertadas no coinciden"; break;
 case "errore nelle funzioni ssl":  		$messaggio = "error en las funciones ssl"; break;
 case "<b class=\"colred\">Attenzione</b>: tutti i dati delle carte di credito verranno cancellati":	$messaggio = "<b class=\"colred\">Atención</b>: todos los datos de las tarjetas de crédito serán borrados"; break;
-case "continua":  				$messaggio = "continua"; break;
+case "continua":  				$messaggio = "continuar"; break;
 case "vecchia password":  			$messaggio = "vieja contraseña"; break;
 case "cambiata":  				$messaggio = "cambiada"; break;
 case "piano":  					$messaggio = "piso"; break;
@@ -403,6 +403,10 @@ case "La tariffa":  				$messaggio = "La tarifa"; break;
 case "è ancora in uso nelle interconnessioni":	$messaggio = "está siendo todavía utilizada en las interconexiones"; break;
 case "almeno 8 caratteri, con lettere e numeri o simboli":	$messaggio = "por lo menos 8 caracteres, con letras y números o símbulos"; break;
 case "diversa dalle ultime":  			$messaggio = "distinta de las últimas"; break;
+case "Condizioni Generali di Contratto":  	$messaggio = "Condiciones Generales del Contrato"; break;
+case "del servizio di memorizzazione delle carte di credito":	$messaggio = "del servicio de almacenamiento de tarjetas de crédito"; break;
+case "La password non è stata modificata":  	$messaggio = "La contraseña no ha sido modificada"; break;
+case "password errata":  			$messaggio = "contraseña equivocada"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
