@@ -349,6 +349,9 @@ case "potrà modificare i <b>documenti come API</b>":	$messaggio = "podrá modif
 case "Attenzione":  				$messaggio = "Atención"; break;
 case "questo può consentire l'accesso ai dati di tutte le prenotazioni":	$messaggio = "esto podrá dar acceso a los datos de todas las reservas"; break;
 case "non potrà più modificare i <b>documenti come API</b>":	$messaggio = "ya no podrá modificar los <b>documentos como API</b>"; break;
+case "Gestione della password per le carte di credito":	$messaggio = "Gestión de la contraseña para las tarjetas de crédito"; break;
+case "potrà gestire la <b>password per le carte di credito</b>":	$messaggio = "podrá gestionar la <b>contraseña para las tarjetas de crédito</b>"; break;
+case "non potrà più gestire la <b>password per le carte di credito</b>":	$messaggio = "ya no podrá gestionar la <b>contraseña para las tarjetas de crédito</b>"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
