@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2016 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -89,9 +89,11 @@ asort ($dati_app['maxocc']);
 reset ($dati_app['maxocc']);
 $dati_app['minocc'] = current($dati_app['maxocc']);
 $lista_tutti_app = ",";
-while (list($key, $val) = each($dati_app['posizione'])) $lista_tutti_app .= "$val,";
+foreach ($dati_app['posizione'] as $val) $lista_tutti_app .= "$val,";
 $dati_app['lista'] = $lista_tutti_app;
 $dati_app['totapp'] = $numappartamenti;
+$dati_app['grp_vicini_num'] = array();
+$dati_app['grp_vicini'] = array();
 for ($num1 = 0 ; $num1 < count($grp_vicini) ; $num1++) {
 if ($grp_vicini[$num1]) {
 $lst_vicini = explode(",",$grp_vicini[$num1]);
@@ -121,7 +123,7 @@ $query_comp = substr($query_comp,0,-3);
 if ($query_comp) $prenota_in_var = esegui_query("select idprenota,idclienti,idappartamenti,iddatainizio,iddatafine,assegnazioneapp,app_assegnabili,num_persone,idprenota_compagna,checkin,datainserimento from $tableprenota where $query_comp ");
 else break;
 } # fine if ($num_rip)
-else $prenota_in_var = esegui_query("select idprenota,idclienti,idappartamenti,iddatainizio,iddatafine,assegnazioneapp,app_assegnabili,num_persone,idprenota_compagna,checkin,datainserimento from $tableprenota where (iddatainizio < '".$limiti_var[ini]."' and iddatafine >= '".$limiti_var[n_ini]."') or (iddatainizio <= '".$limiti_var[n_fine]."' and iddatafine > '".$limiti_var[fine]."')");
+else $prenota_in_var = esegui_query("select idprenota,idclienti,idappartamenti,iddatainizio,iddatafine,assegnazioneapp,app_assegnabili,num_persone,idprenota_compagna,checkin,datainserimento from $tableprenota where (iddatainizio < '".$limiti_var['ini']."' and iddatafine >= '".$limiti_var['n_ini']."') or (iddatainizio <= '".$limiti_var['n_fine']."' and iddatafine > '".$limiti_var['fine']."')");
 $num_prenota_in_var = numlin_query($prenota_in_var);
 for ($num1 = 0 ; $num1 < $num_prenota_in_var ; $num1++) {
 $ins_prenota = 1;
@@ -252,10 +254,10 @@ return $lista_app;
 if (!function_exists('array_keys')) {
 function array_keys($arr,$term="") {
 $t = array();
-while (list($k,$v) = each($arr)) {
+foreach ($arr as $k => $v) {
 if ($term && $v != $term) continue;
 $t[] = $k;
-} # fine while (list($k,$v) = each($arr))
+} # fine foreach ($arr as $k => $v)
 return $t;
 } # fine function array_keys
 } # fine if (!function_exists('array_keys'))
@@ -267,16 +269,16 @@ function aggiorna_tableprenota ($app_prenota_id,$app_orig_prenota_id,$nome_table
 $fatto = 1;
 if (@is_array($app_orig_prenota_id)) {
 reset($app_orig_prenota_id);
-while (list($idprenota, $app_prenota) = each($app_orig_prenota_id)) if (!strcmp($app_prenota_id[$idprenota],"")) $fatto = 0;
+foreach ($app_orig_prenota_id as $idprenota => $app_prenota) if (!strcmp($app_prenota_id[$idprenota],"")) $fatto = 0;
 if ($fatto) {
 reset($app_orig_prenota_id);
-while (list($idprenota, $app_prenota) = each($app_orig_prenota_id)) {
+foreach ($app_orig_prenota_id as $idprenota => $app_prenota) {
 if ($app_prenota_id[$idprenota] != $app_prenota) {
 esegui_query("update $nome_tableprenota set idappartamenti = '".aggslashdb($app_prenota_id[$idprenota])."' where idprenota = '$idprenota'");
 #$adesso = date("Y-M-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 #esegui_query("update $tableprenota set data_modifica = '$adesso' where idprenota = '$idprenota'");
 } # fine if ($app_prenota_id[$idprenota] != $app_prenota)
-} # fine while (list($key, $val) = each($app_orig_prenota_id))
+} # fine foreach ($app_orig_prenota_id as $idprenota => $app_prenota)
 } # fine if ($fatto)
 else echo "<span class=\"colred\">ERROR in assignment engine: please report this bug to <a href=\"mailto:info@digitaldruid.net\">info@digitaldruid.net</a></span><br>";
 } # fine if (@is_array($app_orig_prenota_id))
@@ -289,8 +291,8 @@ return $fatto;
 # function che controlla che gli app. richiesti non siano tutti occupati
 function controlla_tutti_occupati ($idinizio,$idfine,$app_richiesti,&$prenota_in_app_sett,&$app_prenota_id,&$app_assegnabili_id,&$dati_app,&$fine_prenota_id) {
 $tutti_occupati = "NO";
-if ($app_richiesti) while (list($key, $val) = each($app_richiesti)) if ($val != "SI") unset($app_richiesti[$key]);
-if (!$app_richiesti) $num_app_controlla_orig = $dati_app['totapp'];
+if (!empty($app_richiesti)) foreach ($app_richiesti as $key => $val) if ($val != "SI") unset($app_richiesti[$key]);
+if (empty($app_richiesti)) $num_app_controlla_orig = $dati_app['totapp'];
 else $num_app_controlla_orig = count($app_richiesti);
 for ($num1 = $idinizio ; $num1 <= $idfine ; $num1++) {
 $num_prenota_presenti_in_settimana = 0;
@@ -298,12 +300,12 @@ for ($num2 = 0 ; $num2 < $dati_app['totapp'] ; $num2++) {
 if ($prenota_in_app_sett[$dati_app['posizione'][$num2]][$num1]) $num_prenota_presenti_in_settimana++;
 } # fine for $num2
 if ($num_prenota_presenti_in_settimana >= $num_app_controlla_orig) {
-if (!$app_richiesti) { $tutti_occupati = "SI"; break; }
+if (empty($app_richiesti)) { $tutti_occupati = "SI"; break; }
 else {
 $app_controlla = $app_richiesti;
 $uno_libero = "NO";
 reset($app_controlla);
-while (list($key, $val) = each($app_controlla)) {
+foreach ($app_controlla as $key => $val) {
 $prenotainperiodo = prenota_in_app_e_periodo($key,$num1,$num1,$prenota_in_app_sett,$fine_prenota_id,$num_pp);
 if (!$num_pp) { $uno_libero = "SI"; break; }
 $app_assegnabili_prenota = $app_assegnabili_id[$prenotainperiodo[1]];
@@ -316,9 +318,9 @@ $app_assegnabili_prenota = explode (",", $app_assegnabili_prenota);
 $n_app_assegnabili_prenota = count($app_assegnabili_prenota);
 for ($num2 = 0 ; $num2 < $n_app_assegnabili_prenota ; $num2++) if (!$app_controlla[$app_assegnabili_prenota[$num2]]) $app_controlla[$app_assegnabili_prenota[$num2]] = "SI";
 } # fine if ($app_assegnabili_prenota)
-} # fine while (list($key, $val) = each($app_controlla))
+} # fine foreach ($app_controlla as $key => $val)
 if ($uno_libero == "NO") { $tutti_occupati = "SI"; break; }
-} # fine else if (!$app_richiesti)
+} # fine else if (empty($app_richiesti))
 } # fine if ($num_prenota_presenti_in_settimana >= $num_app_controlla_orig)
 } # fine for $num1
 return $tutti_occupati;
@@ -347,18 +349,18 @@ $num_lista_pren_per++;
 # function che cancella le prenotazioni vicine e prepara le variabili per liberasettimane
 function cancella_prenota_compagne ($idprenota_comp,$num_idprenota_comp,&$idinizioprenota,&$idfineprenota,&$app_richiesti,$inizio_prenota_id,$fine_prenota_id,$app_assegnabili_id,$app_prenota_id,&$prenota_in_app_sett) {
 $id_ric = 1;
-$idinizioprenota_vett = "";
-$idfineprenota_vett = "";
+$idinizioprenota_vett = array();
+$idfineprenota_vett = array();
 $idinizioprenota_vett[$id_ric] = $idinizioprenota;
 $idfineprenota_vett[$id_ric] = $idfineprenota;
 $idinizioprenota = $idinizioprenota_vett;
 $idfineprenota = $idfineprenota_vett;
-$app_richiesti_vett = "";
-if (!$app_richiesti) $app_richiesti_vett[$id_ric] = ",tutti,";
+$app_richiesti_vett = array();
+if (empty($app_richiesti)) $app_richiesti_vett[$id_ric] = ",tutti,";
 else {
-while (list($key, $val) = each($app_richiesti)) if ($val == "SI") $app_richiesti_vett[$id_ric] .= $key.",";
+foreach ($app_richiesti as $key => $val) if ($val == "SI") $app_richiesti_vett[$id_ric] .= $key.",";
 $app_richiesti_vett[$id_ric] = substr($app_richiesti_vett[$id_ric],0,-1);
-} # fine else if (!$app_richiesti)
+} # fine else if (empty($app_richiesti)) 
 $app_richiesti = $app_richiesti_vett;
 $app_richiesti[',vicini,'] = "SI";
 $app_richiesti[',numero,'] = $num_idprenota_comp + 1;
@@ -411,14 +413,14 @@ function aggiorna_app_aggiunti (&$limiti_var,&$limiti_var_orig,&$app_orig_prenot
 if ($limiti_var['ini'] < $limiti_var_orig['ini'] or $limiti_var['fine'] > $limiti_var_orig['fine']) {
 if (@is_array($app_orig_prenota_id)) {
 reset($app_orig_prenota_id);
-while (list($idp,$app) = each($app_orig_prenota_id)) {
+foreach ($app_orig_prenota_id as $idp => $app) {
 if (!strcmp($app_prenota_id[$idp],"")) {
 $app_prenota_id[$idp] = $app;
 for ($num1 = $inizio_prenota_id[$idp] ; $num1 <= $fine_prenota_id[$idp] ; $num1++) {
 $prenota_in_app_sett[$app][$num1] = $idp;
 } # fine for $num1
 } # fine if (!strcmp($app_prenota_id[$key2],""))
-} # fine while (list($key2, $val2) = each($app_orig_prenota_id))
+} # fine foreach ($app_orig_prenota_id as $idp => $app)
 } # fine if (@is_array($app_orig_prenota_id))
 } # fine if ($limiti_var['ini'] < $limiti_var_orig['ini'] or...
 } # fine function aggiorna_app_aggiunti
@@ -485,7 +487,7 @@ $limiti_var['n_fine'] = $idfine;
 if (!@is_array($profondita)) {
 $primo_ciclo = "SI";
 $prof_copia = $profondita;
-$profondita = "";
+$profondita = array();
 $profondita['iniziale'] = $prof_copia;
 $profondita['attuale'] = $prof_copia;
 $tableprenota = $nome_tab_prenota . $anno . $profondita['iniziale'];
@@ -517,7 +519,7 @@ $ass00 = 1;
 } # fine if (!$app_assegnabili_id[0][0])
 if (!$app_richiesti_vett[',succ_non_vicino,'][$app_richiesti_vett['id']]) {
 $app_controllati = ",";
-for ($num1 = 0 ; $num1 < $dati_app['totapp'] ; $num1++) if ($dati_app['vicini'][$numapp] == $numapp and (!$app_richiesti or $app_richiesti[$numapp] == "SI")) $app_non_liberabili .= "$numapp,";
+for ($num1 = 0 ; $num1 < $dati_app['totapp'] ; $num1++) if ($dati_app['vicini'][$numapp] == $numapp and (empty($app_richiesti) or $app_richiesti[$numapp] == "SI")) $app_non_liberabili .= "$numapp,";
 if ($app_richiesti_vett['id'] == 1 or $app_richiesti_vett[',succ_non_vicino,'][($app_richiesti_vett['id'] - 1)]) {
 $num_gruppo = 0;
 $num_vicini_tot = 0;
@@ -544,7 +546,7 @@ $app_gruppi_disp = ",";
 $num_app_gruppi_disp = 0;
 for ($num1 = 0 ; $num1 < $dati_app['totapp'] ; $num1++) {
 $numapp = $dati_app['posizione'][$num1];
-if ((!$app_richiesti or $app_richiesti[$numapp] == "SI") and !strstr($app_controllati,",$numapp,") and !strstr($app_non_liberabili,",$numapp,")) {
+if ((empty($app_richiesti) or $app_richiesti[$numapp] == "SI") and !strstr($app_controllati,",$numapp,") and !strstr($app_non_liberabili,",$numapp,")) {
 for ($num2 = 0 ; $num2 < count($dati_app['grp_vicini']) ; $num2++) {
 if (strstr($dati_app['grp_vicini'][$num2],",$numapp,")) {
 $num_vicini_disp = $dati_app['grp_vicini_num'][$num2];
@@ -591,14 +593,14 @@ $app_controllati .= substr($dati_app['grp_vicini'][$num2],1);
 break;
 } # fine if (strstr($dati_app['grp_vicini'][$num2],",$numapp,"))
 } # fine for $num2
-} # fine if ((!$app_richiesti or $app_richiesti[$numapp] == "SI") and !strstr($app_controllati,",$numapp,"))
+} # fine if ((empty($app_richiesti) or $app_richiesti[$numapp] == "SI") and !strstr($app_controllati,",$numapp,"))
 } # fine for $num1
 if ($num_vicini_tot > $num_vicini_disp_tot) $app_non_liberabili .= substr($app_gruppi_disp,1);
 elseif ($num_vicini_tot > $num_vicini and $app_gruppi_disp) {
 for ($num1 = 0 ; $num1 < $dati_app['totapp'] ; $num1++) {
 $numapp = $dati_app['posizione'][$num1];
 if (@is_array($prenota_ricontrolla_tot[$numapp])) {
-while (list($num_pp,$vett_assegnabili) = each($prenota_ricontrolla_tot[$numapp])) {
+foreach ($prenota_ricontrolla_tot[$numapp] as $num_pp => $vett_assegnabili) {
 $num_assegnabili = count($vett_assegnabili);
 if ($num_assegnabili <= $num_app_gruppi_disp) {
 $contenuto = 1;
@@ -613,7 +615,7 @@ $num_vicini_disp_tot--;
 break;
 } # fine if ($contenuto)
 } # fine if ($num_assegnabili <= $num_app_gruppi_disp)
-} # fine while (list($num_pp,$vett_assegnabili) = each($prenota_ricontrolla_tot[$numapp]))
+} # fine foreach ($prenota_ricontrolla_tot[$numapp] as $num_pp => $vett_assegnabili)
 if ($num_vicini_tot > $num_vicini_disp_tot) {
 $app_non_liberabili .= substr($app_gruppi_disp,1);
 break;
@@ -632,7 +634,7 @@ break;
 if ($fatto != "SI") {
 for ($num1 = 0 ; $num1 < $dati_app['totapp'] ; $num1++) {
 $numapp = $dati_app['posizione'][$num1];
-if (!$app_richiesti or $app_richiesti[$numapp] == "SI") {
+if (empty($app_richiesti) or $app_richiesti[$numapp] == "SI") {
 if (!strstr($app_non_liberabili,",$numapp,")) {
 $prenotainperiodo = prenota_in_app_e_periodo($numapp,$idinizio,$idfine,$prenota_in_app_sett,$fine_prenota_id,$num_pp);
 if (!$num_pp) {
@@ -642,14 +644,14 @@ if ($debug == "on") echo "LIBERATO1 $appartamento<br>";
 break;
 } # fine if (!$num_pp)
 } # fine if (!strstr($app_non_liberabili,",$numapp,"))
-} # fine if (!$app_richiesti or $app_richiesti[$numapp] == "SI")
+} # fine if (empty($app_richiesti) or $app_richiesti[$numapp] == "SI")
 } # fine for $num1
 } # fine if ($fatto != "SI")
 
 if ($fatto != "SI") {
 
 # allargo il periodo passato dalla tabella alle variabili se necessario
-$lista_prenota_periodo = "";
+$lista_prenota_periodo = array();
 $pren_pres_in_lista = "";
 $num_lista_pren_per = 0;
 if (!$limiti_var[s_ini]) {
@@ -677,7 +679,7 @@ tab_a_var ($limiti_var,$app_prenota_id,$app_orig_prenota_id,$inizio_prenota_id,$
 # mette in $da_liberare o $da_scambiare
 for ($num1 = 0 ; $num1 < $dati_app['totapp'] ; $num1++) {
 $numapp = $dati_app['posizione'][$num1];
-if (!$app_richiesti or $app_richiesti[$numapp] == "SI") {
+if (empty($app_richiesti) or $app_richiesti[$numapp] == "SI") {
 $prenotainperiodo = prenota_in_app_e_periodo($numapp,$idinizio,$idfine,$prenota_in_app_sett,$fine_prenota_id,$num_pp);
 $idiniziop = "";
 $idfinep = "";
@@ -811,7 +813,7 @@ else $riprova_app[$numapp] = "NO";
 if ($fatto == "SI") { break; }
 } # fine if ($mobile == "SI")
 else $riprova_app[$numapp] = "NO";
-} # fine if (!$app_richiesti or $app_richiesti[$numapp] == "SI")
+} # fine if (empty($app_richiesti) or $app_richiesti[$numapp] == "SI")
 } # fine for $num1
 
 } # fine if ($fatto != "SI")
