@@ -23,7 +23,7 @@
 
 
 
-$var_mod = "";
+$var_mod = array();
 
 $var_mod[0] = "estendi_ultima_data";
 $var_mod[1] = "periodi_menu";
@@ -166,7 +166,7 @@ $$variabile = trim($$variabile);
 if (substr($$variabile,0,1) == "\"" and substr($$variabile,-1) == "\"") $$variabile =  substr($$variabile,1,-1);
 if (substr(str_replace(" ","",$$variabile),0,6) == "array(") {
 $vett = $$variabile;
-$$variabile = "";
+$$variabile = array();
 ${$variabile}['array_esistente'] = "SI";
 $vett = preg_replace("/^array[ ]*\(/","",$vett);
 if (substr($vett,-1) == ")") $vett = substr($vett,0,-1);
@@ -742,17 +742,17 @@ if (strtoupper(\$".mex("var_estendi_ultima_data",$pag).") == \"".mex("SI",$pag).
 else \$estendi_ultima_data = \"NO\";
 unset(\$tariffe_mostra);
 reset (\$".mex("var_tariffe_mostra",$pag).");
-while (list (\$key, \$val) = each (\$".mex("var_tariffe_mostra",$pag).")) {
+foreach (\$".mex("var_tariffe_mostra",$pag)." as \$key => \$val) {
 if (strtoupper(\$val) == \"".mex("SI",$pag)."\") \$tariffe_mostra[\$key] = \"SI\";
 if (strtoupper(\$val) == \"".mex("NO",$pag)."\") \$tariffe_mostra[\$key] = \"NO\";
-} # fine while
+} # fine foreach
 \$n_tariffe_imposte = \$".mex("var_nomi_tariffe_imposte",$pag).";
 unset(\$motivazioni_regola1);
 reset (\$".mex("var_considera_motivazioni_regola1",$pag).");
-while (list (\$key, \$val) = each (\$".mex("var_considera_motivazioni_regola1",$pag).")) {
+foreach (\$".mex("var_considera_motivazioni_regola1",$pag)." as \$key => \$val) {
 if (strtoupper(\$val) == \"".mex("SI",$pag)."\") \$motivazioni_regola1[\$key] = \"SI\";
 if (strtoupper(\$val) == \"".mex("NO",$pag)."\") \$motivazioni_regola1[\$key] = \"NO\";
-} # fine while
+} # fine foreach
 \$data_preselezionata = \$".mext_cal("var_data_preselezionata",$pag).";
 \$numero_giorni = \$".mext_cal("var_numero_giorni",$pag).";
 if (strtoupper(\$".mex("var_allinea_disponibilita_con_arrivo",$pag).") == \"".mex("SI",$pag)."\") \$allinea_disponibilita_con_arrivo = \"SI\";
@@ -802,8 +802,8 @@ fwrite($file,"
 
 \$numconnessione = connetti_db(\$PHPR_DB_NAME,\$PHPR_DB_HOST,\$PHPR_DB_PORT,\$PHPR_DB_USER,\$PHPR_DB_PASS,\$PHPR_LOAD_EXT);
 ");
-includi_file("./includes/funzioni.php",$file);
 includi_file(C_DATI_PATH."/versione.php",$file);
+includi_file("./includes/funzioni.php",$file);
 includi_file("./includes/liberasettimane.php",$file);
 includi_file("./includes/funzioni_tariffe.php",$file);
 includi_file("./includes/funzioni_quadro_disp.php",$file);
