@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -23,7 +23,7 @@
 
 
 
-$var_mod = "";
+$var_mod = array();
 
 $var_mod[0] = "estendi_ultima_data";
 $var_mod[1] = "mostra_date_passate";
@@ -161,8 +161,8 @@ $$variabile = trim($$variabile);
 if (substr($$variabile,0,1) == "\"" and substr($$variabile,-1) == "\"") $$variabile =  substr($$variabile,1,-1);
 if (substr(str_replace(" ","",$$variabile),0,6) == "array(") {
 $vett = $$variabile;
-$$variabile = "";
-${$variabile}["array_esistente"] = "SI";
+$$variabile = array();
+${$variabile}['array_esistente'] = "SI";
 $vett = preg_replace("/^array[ ]*\(/","",$vett);
 if (substr($vett,-1) == ")") $vett = substr($vett,0,-1);
 if (strcmp(trim($vett),"")) {
@@ -259,7 +259,7 @@ if (strtoupper($mostra_date_passate) == $NO) $mostra_date_passate = "NO";
 else $mostra_date_passate = "SI";
 $tablenometariffe_modello = $PHPR_TAB_PRE."ntariffe".$anno_modello;
 $rigatariffe = esegui_query("select * from $tablenometariffe_modello where idntariffe = 1 ");
-$numero_tariffe = risul_query($rigatariffe,0,nomecostoagg);
+$numero_tariffe = risul_query($rigatariffe,0,'nomecostoagg');
 for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) {
 $tariffa = "tariffa".$numtariffa;
 $nome_tariffa_imposto = "nome_tariffa_imposto".$numtariffa;
@@ -270,13 +270,13 @@ if (strtoupper($tariffe_mostra[$numtariffa]) == $SI) $$tariffa = "SI";
 $$nome_tariffa_imposto = $nomi_tariffe_imposte[$numtariffa];
 } # fine for $numtariffa
 $dati_ca = dati_costi_agg_ntariffe($tablenometariffe_modello,"NO");
-for ($numca = 0 ; $numca < $dati_ca[num] ; $numca++) {
-$attiva_costo = "attiva_costo".$dati_ca[$numca][id];
-$nome_costo_imposto = "nome_costo_imposto".$dati_ca[$numca][id];
+for ($numca = 0 ; $numca < $dati_ca['num'] ; $numca++) {
+$attiva_costo = "attiva_costo".$dati_ca[$numca]['id'];
+$nome_costo_imposto = "nome_costo_imposto".$dati_ca[$numca]['id'];
 global $$attiva_costo,$$nome_costo_imposto;
 $$attiva_costo = "";
-if (strtoupper($costi_aggiuntivi_mostra[$dati_ca[$numca][id]]) == $SI) $$attiva_costo = "SI";
-$$nome_costo_imposto = $nomi_costi_agg_imposti[$dati_ca[$numca][id]];
+if (strtoupper($costi_aggiuntivi_mostra[$dati_ca[$numca]['id']]) == $SI) $$attiva_costo = "SI";
+$$nome_costo_imposto = $nomi_costi_agg_imposti[$dati_ca[$numca]['id']];
 } # fine for $numca
 if (strtoupper($mostra_caparra) == $SI) $mostra_caparra = "SI";
 else $mostra_caparra = "NO";
@@ -329,7 +329,7 @@ $fineperiodo = aggslashdb(${"fineperiodo".$num1});
 $idinizioperiodo = esegui_query("select idperiodi from $tableperiodi_modello where datainizio = '$inizioperiodo' ");
 $num_idinizioperiodo = numlin_query($idinizioperiodo);
 if ($num_idinizioperiodo == 0) { $idinizioperiodo = 10000; }
-else { $idinizioperiodo = risul_query($idinizioperiodo,0,idperiodi); }
+else { $idinizioperiodo = risul_query($idinizioperiodo,0,'idperiodi'); }
 $inizioperiodo = $idinizioperiodo;
 if ($estendi_ultima_data == "SI" and $num1 == ($num_periodi_date - 1)) {
 $idfineperiodo = esegui_query("select max(idperiodi) from $tableperiodi_modello");
@@ -339,7 +339,7 @@ else {
 $idfineperiodo = esegui_query("select idperiodi from $tableperiodi_modello where datafine = '$fineperiodo' ");
 $num_idfineperiodo = numlin_query($idfineperiodo);
 if ($num_idfineperiodo == 0) { $idfineperiodo = -1; }
-else { $idfineperiodo = risul_query($idfineperiodo,0,idperiodi); }
+else { $idfineperiodo = risul_query($idfineperiodo,0,'idperiodi'); }
 } # fine else if ($estendi_ultima_data == "SI" and $num1 == ($num_periodi_date - 1))
 $fineperiodo = $idfineperiodo ;
 ${"inizioperiodo".$num1} = $inizioperiodo;
@@ -368,10 +368,10 @@ if (substr($file_intero[$num2],0,7) == "<option") {
 $data_option = substr($file_intero[$num2],16,10);
 $id_data_option = esegui_query("select idperiodi from $tableperiodi_modello where datainizio = '$data_option' ");
 $esiste_data_option = numlin_query($id_data_option);
-if ($esiste_data_option == 1) $id_data_option = risul_query($id_data_option,0,idperiodi);
+if ($esiste_data_option == 1) $id_data_option = risul_query($id_data_option,0,'idperiodi');
 else {
 $id_data_option = esegui_query("select idperiodi from $tableperiodi_modello where datafine = '$data_option' ");
-$id_data_option = risul_query($id_data_option,0,idperiodi);
+$id_data_option = risul_query($id_data_option,0,'idperiodi');
 } # fine else if ($esiste_data_option == 1)
 if ($id_data_option >= $inizioperiodo and $id_data_option <= ($fineperiodo + 1)) {
 if ($num_intervallo == 1) {
@@ -422,7 +422,7 @@ $dati_ca = dati_costi_agg_ntariffe($tablenometariffe_modello,"NO");
 if ($continua != "NO") {
 
 $rigatariffe = esegui_query("select * from $tablenometariffe_modello where idntariffe = 1 ");
-$numero_tariffe = risul_query($rigatariffe,0,nomecostoagg);
+$numero_tariffe = risul_query($rigatariffe,0,'nomecostoagg');
 $tariffe_mostra = "";
 $nomi_tariffe_imposte = "";
 for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) {
@@ -439,14 +439,14 @@ if ($nomi_tariffe_imposte) $nomi_tariffe_imposte = substr($nomi_tariffe_imposte,
 
 unset($nomi_costi_imposti);
 unset($costi_attivati);
-for ($numca = 0 ; $numca < $dati_ca[num] ; $numca++) {
-global ${"attiva_costo".$dati_ca[$numca][id]};
-if (${"attiva_costo".$dati_ca[$numca][id]} == "SI") {
-$costi_attivati .= " ".$dati_ca[$numca][id]." => \"".mex("SI",$pag)."\",";
-$nome_costo_imposto = "nome_costo_imposto".$dati_ca[$numca][id];
+for ($numca = 0 ; $numca < $dati_ca['num'] ; $numca++) {
+global ${"attiva_costo".$dati_ca[$numca]['id']};
+if (${"attiva_costo".$dati_ca[$numca]['id']} == "SI") {
+$costi_attivati .= " ".$dati_ca[$numca]['id']." => \"".mex("SI",$pag)."\",";
+$nome_costo_imposto = "nome_costo_imposto".$dati_ca[$numca]['id'];
 global $$nome_costo_imposto;
 $$nome_costo_imposto = formatta_input_var_x_file($$nome_costo_imposto);
-if ($$nome_costo_imposto) $nomi_costi_imposti .= $dati_ca[$numca][id]." => \"".$$nome_costo_imposto."\",";
+if ($$nome_costo_imposto) $nomi_costi_imposti .= $dati_ca[$numca]['id']." => \"".$$nome_costo_imposto."\",";
 } # fine if (${"attiva_costo".$dati_ca[$numca][id]} == "SI")
 } # fine for $num1
 if ($nomi_costi_imposti) $nomi_costi_imposti = substr($nomi_costi_imposti,0,-1);
@@ -707,17 +707,17 @@ if (strtoupper(\$".mex("var_mostra_date_passate",$pag).") == \"".mex("NO",$pag).
 else \$mostra_date_passate = \"SI\";
 unset(\$tariffe_mostra);
 reset (\$".mex("var_tariffe_mostra",$pag).");
-while (list (\$key, \$val) = each (\$".mex("var_tariffe_mostra",$pag).")) {
+foreach (\$".mex("var_tariffe_mostra",$pag)." as \$key => \$val) {
 if (strtoupper(\$val) == \"".mex("SI",$pag)."\") \$tariffe_mostra[\$key] = \"SI\";
 if (strtoupper(\$val) == \"".mex("NO",$pag)."\") \$tariffe_mostra[\$key] = \"NO\";
-} # fine while
+} # fine foreach
 \$n_tariffe_imposte = \$".mex("var_nomi_tariffe_imposte",$pag).";
 unset(\$costi_agg_mostra);
 reset (\$".mex("var_costi_aggiuntivi_mostra",$pag).");
-while (list (\$key, \$val) = each (\$".mex("var_costi_aggiuntivi_mostra",$pag).")) {
+foreach (\$".mex("var_costi_aggiuntivi_mostra",$pag)." as \$key => \$val) {
 if (strtoupper(\$val) == \"".mex("SI",$pag)."\") \$costi_agg_mostra[\$key] = \"SI\";
 if (strtoupper(\$val) == \"".mex("NO",$pag)."\") \$costi_agg_mostra[\$key] = \"NO\";
-} # fine while
+} # fine foreach
 \$n_costi_agg_imposti = \$".mex("var_nomi_costi_agg_imposti",$pag).";
 if (strtoupper(\$".mex("var_mostra_caparra",$pag).") == \"".mex("SI",$pag)."\") \$mostra_caparra = \"SI\";
 else \$mostra_caparra = \"NO\";
@@ -755,8 +755,8 @@ fwrite($file,"
 
 \$numconnessione = connetti_db(\$PHPR_DB_NAME,\$PHPR_DB_HOST,\$PHPR_DB_PORT,\$PHPR_DB_USER,\$PHPR_DB_PASS,\$PHPR_LOAD_EXT);
 ");
-includi_file("./includes/funzioni.php",$file);
 includi_file(C_DATI_PATH."/versione.php",$file);
+includi_file("./includes/funzioni.php",$file);
 includi_file("./includes/funzioni_testo.php",$file);
 includi_file("./includes/funzioni_tariffe.php",$file);
 includi_file("./includes/funzioni_costi_agg.php",$file);
@@ -815,7 +815,7 @@ if ($silenzio == "NO") {
 if (defined("C_CARTELLA_CREA_MODELLI")) echo mex("Si può creare un link verso questa pagina dal proprio sito internet",$pag).".<br>";
 else echo mex("Si può cambiare la directory dove vengono create le pagine da \"configura e personalizza\"",$pag).".<br>";
 
-if (defined("C_FILE_DOMINIO") and C_FILE_DOMINIO != "" and C_NASCONDI_MARCA != "SI") {
+if (defined("C_FILE_DOMINIO") and C_FILE_DOMINIO != "" and (!defined('C_NASCONDI_MARCA') or C_NASCONDI_MARCA != "SI")) {
 $altri_domini = @file(C_FILE_DOMINIO);
 if ($altri_domini) {
 if (defined("C_CARTELLA_CREA_MODELLI") and C_CARTELLA_CREA_MODELLI != "") $percorso_cartella_dominio = substr($percorso_cartella_modello,strlen(C_CARTELLA_CREA_MODELLI));
@@ -837,7 +837,7 @@ $lista_altri_domini .= "<br>";
 } # fine for $num1
 if ($lista_altri_domini) echo "<br><br>".mex("Indirizzi alternativi da cui la pagina è raggiungibile",$pag).":<br><div class=\"linhbox\">$lista_altri_domini</div>";
 } # fine if ($altri_domini)
-} # fine if (defined("C_FILE_DOMINIO") and C_FILE_DOMINIO != "" and C_NASCONDI_MARCA != "SI")
+} # fine if (defined("C_FILE_DOMINIO") and C_FILE_DOMINIO != "" and (!defined('C_NASCONDI_MARCA') or C_NASCONDI_MARCA != "SI"))
 
 echo "<br>";
 } # fine if ($silenzio == "NO")
