@@ -21,7 +21,7 @@
 ##################################################################################
 
 
-$var_predef = "";
+$var_predef = array();
 
 $var_predef[0] = "cognome";
 $var_predef[1] = "nome";
@@ -319,7 +319,7 @@ $numero_ins_comm_pers = $numero_ins_comm_pers + $num_campi_pers_cliente;
 
 
 
-$var_predef_data = "";
+$var_predef_data = array();
 
 $var_predef_data['data_nascita'] = 1;
 $var_predef_data['scadenza_documento'] = 1;
@@ -337,7 +337,7 @@ $var_predef_data['oggi'] = 1;
 
 
 
-$var_riserv = "";
+$var_riserv = array();
 
 $var_riserv['contratto'] = 1;
 $var_riserv['filecontr'] = 1;
