@@ -53,7 +53,7 @@ if (@is_dir("./includes/lang/en")) $lingua_mex = "en";
 else $lingua_mex = "ita";
 if (@isset($_SERVER['HTTP_ACCEPT_LANGUAGE'])) {
 $lingua_browser = explode(",",$_SERVER['HTTP_ACCEPT_LANGUAGE']);
-while (list($ind,$lang) = each($lingua_browser)) {
+foreach ($lingua_browser as $lang) {
 if ($lang == "en") break;
 if ($lang == "it") {
 $lingua_mex = "ita";
@@ -63,7 +63,7 @@ if (strlen($lang) == 2 and @is_dir("./includes/lang/$lang")) {
 $lingua_mex = $lang;
 break;
 } # fine if (strlen($lang) == 2 and @is_dir("./includes/lang/$lang"))
-} # fine (list($ind,$lang) = each($lingua_browser))
+} # fine foreach ($lingua_browser as $lang)
 } # fine if (@isset($_SERVER['HTTP_ACCEPT_LANGUAGE']))
 if (@is_file("./COPYING")) $file_copying = "file <a href=\"COPYING\">COPYING</a>";
 else $file_copying = "<a href=\"http://www.gnu.org/licenses/agpl-3.0.html\">AGPLv3</a> License";
@@ -99,11 +99,11 @@ else include("./includes/foot.php");
 
 else {
 
-if (C_CREA_ULTIMO_ACCESSO == "SI") {
+if (defined('C_CREA_ULTIMO_ACCESSO') and C_CREA_ULTIMO_ACCESSO == "SI") {
 $fileaperto = @fopen(C_DATI_PATH."/ultimo_accesso","w+");
 @fwrite($fileaperto,date("d-m-Y H:i:s"));
 @fclose($fileaperto);
-} # fine if (C_CREA_ULTIMO_ACCESSO == "SI")
+} # fine if (defined('C_CREA_ULTIMO_ACCESSO') and C_CREA_ULTIMO_ACCESSO == "SI")
 
 if ($id_utente != 1) {
 $tableprivilegi = $PHPR_TAB_PRE."privilegi";
@@ -117,6 +117,7 @@ $priv_mod_pers = risul_query($privilegi_globali_utente,0,'priv_mod_pers');
 if (substr($priv_mod_pers,0,1) != "s") $modifica_pers = "NO";
 $priv_crea_backup = substr($priv_mod_pers,1,1);
 $priv_crea_interconnessioni = substr($priv_mod_pers,3,1);
+$priv_gest_pass_cc = substr($priv_mod_pers,5,1);
 $priv_ins_clienti = risul_query($privilegi_globali_utente,0,'priv_ins_clienti');
 if (substr($priv_ins_clienti,0,1) != "s") $inserimento_nuovi_clienti = "NO";
 if (substr($priv_ins_clienti,1,1) != "s" and substr($priv_ins_clienti,1,1) != "p" and substr($priv_ins_clienti,1,1) != "g") $modifica_clienti = "NO";
@@ -175,6 +176,7 @@ $anno_utente_attivato = "SI";
 $modifica_pers = "SI";
 $priv_crea_backup = "s";
 $priv_crea_interconnessioni = "s";
+$priv_gest_pass_cc = "s";
 $inserimento_nuovi_clienti = "SI";
 $modifica_clienti = "SI";
 $vedi_clienti = "SI";
@@ -304,7 +306,7 @@ $id_sessione = $n_id_sessione;
 if ($tema[$id_utente] != "base") include("./themes/".$tema[$id_utente]."/php/head.php");
 else include("./includes/head.php");
 
-if (!$numconnessione and C_MOSTRA_COPYRIGHT != "NO") echo "<table style=\"background-color: #ffffff; width: 99%; height: 97%; margin-right: auto; margin-left: auto;\" border=\"0\" cellpadding=\"0\" cellspacing=\"0\"><tr><td style=\"vertical-align: top;\">";
+if (!$numconnessione and (!defined('C_MOSTRA_COPYRIGHT') or C_MOSTRA_COPYRIGHT != "NO")) echo "<table style=\"background-color: #ffffff; width: 99%; height: 97%; margin-right: auto; margin-left: auto;\" border=\"0\" cellpadding=\"0\" cellspacing=\"0\"><tr><td style=\"vertical-align: top;\">";
 
 echo "$form_aggiorna_sub";
 
@@ -537,7 +539,7 @@ if ($priv_vedi_tab_prenotazioni == "p" or $priv_vedi_tab_prenotazioni == "g") {
 $condizione_prenota_proprie = "and ( utente_inserimento = '$id_utente'";
 if ($priv_vedi_tab_prenotazioni == "g") {
 reset($utenti_gruppi);
-while (list($idut_gr,$val) = each($utenti_gruppi)) if ($idut_gr != $id_utente) $condizione_prenota_proprie .= " or utente_inserimento = '$idut_gr'";
+foreach ($utenti_gruppi as $idut_gr => $val) if ($idut_gr != $id_utente) $condizione_prenota_proprie .= " or utente_inserimento = '$idut_gr'";
 } # fine if ($priv_vedi_tab_prenotazioni == "g")
 $condizione_prenota_proprie .= " )";
 } # fine if ($priv_vedi_tab_prenotazioni == "p" or $priv_vedi_tab_prenotazioni == "g")
@@ -567,7 +569,8 @@ else {
 $class_opt = "";
 $class_opt2 = "";
 } # fine else if ($mobile_device)
-echo "<table class=\"t1 ckin\" style=\"background-color: $t1color; margin-left: auto; margin-right: auto;\" width=780 border=\"$t1border\" cellspacing=\"$t1cellspacing\">
+echo "<div class=\"tab_cont\">
+<table class=\"t1 ckin\" style=\"background-color: $t1color; margin-left: auto; margin-right: auto;\" width=780 border=\"$t1border\" cellspacing=\"$t1cellspacing\">
 <tr><td><span class=\"wsnw\">N&deg;</span></td>
 <td><small>".str_replace(" ","&nbsp;",mex("Cognome del cliente",$pag))."</small></td>
 <td>".str_replace(" ","&nbsp;",mex("Data iniziale",$pag));
@@ -724,7 +727,7 @@ if ($checkin and !$checkout)  echo "<td colspan=2>".mex("Uscita",$pag)."</td>";
 echo "</tr>";
 
 } # fine for $num1
-echo "</table>
+echo "</table></div>
 <hr id=\"mm_sub6\" style=\"width: 95%;\">";
 } # fine if ($num_prenotazioni > 0)
 } # fine if ($attiva_checkin == "SI")
@@ -745,13 +748,13 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"crearegole.php\"><
 <button class=\"irul\" type=\"submit\"><div>".mex("Inserisci o modifica le regole di assegnazione",$pag)."</div></button><br>
 </div></form><div class=\"mm_sub7\"></div>";
 } # fine if ($id_utente == 1 and $installazione_subordinata != "SI")
-if ($modifica_pers != "NO" or $priv_crea_backup == "s"or $priv_crea_interconnessioni == "s") {
+if ($modifica_pers != "NO" or $priv_crea_backup == "s" or $priv_crea_interconnessioni == "s" or $priv_gest_pass_cc == "s") {
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"personalizza.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <button class=\"conf\" type=\"submit\"><div>".mex("Configura e personalizza",$pag)."</div></button><br>
 </div></form><div class=\"mm_sub7\"></div>";
-} # fine if ($modifica_pers != "NO" or $priv_crea_backup == "s"or $priv_crea_interconnessioni == "s")
+} # fine if ($modifica_pers != "NO" or $priv_crea_backup == "s" or $priv_crea_interconnessioni == "s" or $priv_gest_pass_cc == "s")
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"inizio.php\"><div>
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 ".ucfirst(mex("richiedi l'anno",$pag))."
@@ -764,13 +767,13 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"inizio.php\"><div>
 } # fine if (!$hide_default_menu)
 
 # You are not authorized to remove the following copyright notice. Ask for permission info@digitaldruid.net
-if (!$numconnessione and C_MOSTRA_COPYRIGHT != "NO") {
+if (!$numconnessione and (!defined('C_MOSTRA_COPYRIGHT') or C_MOSTRA_COPYRIGHT != "NO")) {
 echo "</td></tr>
 <tr><td style=\"background-color: #ffffff; height: 57px; color: #000000; font-size: 11px; text-align: center; vertical-align: bottom;\">
 Website <a style=\"color: #000000;\" href=\"./mostra_sorgente.php\">engine code</a> is copyright © by DigitalDruid.Net.
 <a style=\"color: #000000;\" href=\"http://www.hoteldruid.com\">HotelDruid</a> is a free software released under the GNU/AGPL.
 </td></tr></table>";
-} # fine if (!$numconnessione and C_MOSTRA_COPYRIGHT != "NO")
+} # fine if (!$numconnessione and (!defined('C_MOSTRA_COPYRIGHT') or C_MOSTRA_COPYRIGHT != "NO"))
 
 if ($tema[$id_utente] != "base") include("./themes/".$tema[$id_utente]."/php/foot.php");
 else include("./includes/foot.php");
@@ -790,7 +793,7 @@ if ($tema[$id_utente] != "base") include("./themes/".$tema[$id_utente]."/php/hea
 else include("./includes/head.php");
 echo "$form_aggiorna_sub";
 
-if (controlla_anno($anno) == "NO" or $id_utente != 1 or $installazione_subordinata == "SI" or (C_CREA_ANNO_NON_ATTUALE == "NO" and $anno != $anno_corrente)) {
+if (controlla_anno($anno) == "NO" or $id_utente != 1 or $installazione_subordinata == "SI" or (defined('C_CREA_ANNO_NON_ATTUALE') and C_CREA_ANNO_NON_ATTUALE == "NO" and $anno != $anno_corrente)) {
 if (controlla_anno($anno) == "SI" and $id_utente != 1) echo mex("Questo utente non ha i privilegi per creare nuovi anni",$pag).".<br>";
 else echo mex("Il formato dell'anno richiesto è sbagliato",$pag).".<br>";
 } # fine if (controlla_anno($anno) == "NO" or $id_utente != 1 or $installazione_subordinata == "SI" or...
@@ -822,7 +825,7 @@ $tipo_periodi_esistenti = esegui_query("select * from $tableanni order by idanni
 if (numlin_query($tipo_periodi_esistenti) != 0) $tipo_periodi_prec = risul_query($tipo_periodi_esistenti,0,'tipo_periodi');
 if ($tipo_periodi_prec == "s") $checked_s = " checked";
 else $checked_g = " checked";
-if (C_CAMBIA_TIPO_PERIODI == "NO") $tipo_periodi_obbligati = $tipo_periodi_prec;
+if (defined('C_CAMBIA_TIPO_PERIODI') and C_CAMBIA_TIPO_PERIODI == "NO") $tipo_periodi_obbligati = $tipo_periodi_prec;
 if (!$tipo_periodi_obbligati or $tipo_periodi_obbligati == "s") {
 echo "<label><input type=\"radio\" name=\"tipo_periodi\" value=\"s\"$checked_s>
 ".mex("settimanali",$pag)."</label> (<em>".mex("obsoleti",$pag)."</em>): 
