@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2009 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -224,7 +224,7 @@ $id_utente_esist = risul_query($id_esist,0,'utente_inserimento');
 $utente_trovato = "NO";
 if ($id_utente == $id_utente_esist) $utente_trovato = "SI";
 $utente_trovato_gr = $utente_trovato;
-while (list($idut_gr,$val) = each($utenti_gruppi)) if ($idut_gr == $id_utente_esist) $utente_trovato_gr = "SI";
+foreach ($utenti_gruppi as $idut_gr => $val) if ($idut_gr == $id_utente_esist) $utente_trovato_gr = "SI";
 if ($priv_vedi_inv_mag == "p" and $utente_trovato != "SI") $priv_vedi_inv = "n";
 if ($priv_vedi_inv_mag == "g" and $utente_trovato_gr != "SI") $priv_vedi_inv = "n";
 if ($priv_ins_beni == "p" and $utente_trovato != "SI") $priv_ins_beni = "n";
@@ -256,7 +256,7 @@ if ($priv_vedi_beni_inv == "p" or $priv_vedi_beni_inv == "g") {
 $condizione_beni_propri = "where ( utente_inserimento = '$id_utente'";
 if ($priv_vedi_beni_inv == "g") {
 reset($utenti_gruppi);
-while (list($idut_gr,$val) = each($utenti_gruppi)) if ($idut_gr != $id_utente) $condizione_beni_propri .= " or utente_inserimento = '$idut_gr'";
+foreach ($utenti_gruppi as $idut_gr => $val) if ($idut_gr != $id_utente) $condizione_beni_propri .= " or utente_inserimento = '$idut_gr'";
 } # fine if ($priv_vedi_beni_inv == "g")
 $condizione_beni_propri .= " )";
 } # fine if ($priv_vedi_beni_inv == "p" or $priv_vedi_beni_inv == "g")
@@ -337,7 +337,7 @@ echo "<table cellpadding=\"0\" cellspacing=\"0\"><tr>
 <label><input type=\"radio\" id=\"tc_e\" name=\"tipo_categoria_ca\" value=\"ce\">".mex("esistente",$pag).":
  </label><select name=\"categoria_esist_ca\" onfocus=\"document.getElementById('tc_e').checked='1'\">";
 reset($categorie);
-while (list($cat_es,$val) = each($categorie)) echo "<option value=\"".htmlspecialchars($cat_es)."\">".htmlspecialchars($cat_es)."</option>";
+foreach ($categorie as $cat_es => $val) echo "<option value=\"".htmlspecialchars($cat_es)."\">".htmlspecialchars($cat_es)."</option>";
 echo "</select></td></tr></table>";
 } # fine else if (!$num_categorie_esist)
 echo "<div style=\"height: 5px;\"></div>
@@ -473,7 +473,7 @@ if ($priv_vedi_inv_mag == "p" or $priv_vedi_inv_mag == "g") {
 $condizione_mag_propri = "where ( utente_inserimento = '$id_utente'";
 if ($priv_vedi_inv_mag == "g") {
 reset($utenti_gruppi);
-while (list($idut_gr,$val) = each($utenti_gruppi)) if ($idut_gr != $id_utente) $condizione_mag_propri .= " or utente_inserimento = '$idut_gr'";
+foreach ($utenti_gruppi as $idut_gr => $val) if ($idut_gr != $id_utente) $condizione_mag_propri .= " or utente_inserimento = '$idut_gr'";
 } # fine if ($priv_vedi_inv_mag == "g")
 $condizione_mag_propri .= " )";
 } # fine if ($priv_vedi_inv_mag == "p" or $priv_vedi_inv_mag == "g")
@@ -827,8 +827,16 @@ echo "<td><select name=\"ric_checkin\">
 echo "<td><button class=\"plum\" type=\"submit\" name=\"aggiungi_bene\" value=\"1\"><div>".mex("aggiungi",$pag)."</div></button></td></tr>";
 } # fine if ($opt_beni and $priv_ins_beni != "n")
 
+if ($num_beni_in_mag > 15) {
+$id_modi = " id=\"modi\"";
+$id_indi = " id=\"indi\"";
+} # fine if ($num_beni_in_mag > 15)
+else {
+$id_modi = "";
+$id_indi = "";
+} # fine else if ($num_beni_in_mag > 15)
 echo "</table><br><div style=\"text-align: center;\">";
-if ($priv_mod_beni != "n") echo "<button class=\"ainv\" type=\"submit\" name=\"modifica_quantita\" value=\"1\"><div>".mex("Modifica le quantità attuali",$pag)."</div></button>";
+if ($priv_mod_beni != "n") echo "<button$id_modi class=\"ainv\" type=\"submit\" name=\"modifica_quantita\" value=\"".mex("Modifica le quantità attuali",$pag)."\"><div>".mex("Modifica le quantità attuali",$pag)."</div></button>";
 echo "</div></div></form>
 $frase_modifica<br>";
 
@@ -839,7 +847,7 @@ echo "<hr style=\"width: 95%\"><br><div style=\"text-align: center;\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"tipo_tabella\" value=\"$tipo_tabella\">";
 if ($origine_vecchia) echo "<input type=\"hidden\" name=\"origine\" value=\"$origine_vecchia\">";
-echo "<button class=\"gobk\" type=\"submit\"><div>".mex("Torna indietro",$pag)."</div></button>
+echo "<button$id_indi class=\"gobk\" type=\"submit\"><div>".mex("Torna indietro",$pag)."</div></button>
 </div></form><br></div>";
 
 } # fine if ($mostra_form_inventario != "NO")
