@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2014 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -772,6 +772,7 @@ return $tasto_prenota;
 } # fine function crea_tasto_modifica_prenota
 
 echo "$stringa_pagine
+<div class=\"tab_cont\">
 <table class=\"me1\" style=\"background-color: $t1color; margin-left: auto; margin-right: auto;\" border=\"$t1border\" cellspacing=\"$t1cellspacing\" cellpadding=\"$t1cellpadding\">
 <tr><td align=\"center\">".mex("N°",$pag)."</td>
 <td align=\"center\">".mex("Mittente",$pag)."</td>
@@ -1133,7 +1134,7 @@ $tasto_contr
 
 
 if ($stringa_pagine and $pagina_messaggi != $num_pagine) echo $stringa_puntini_tab;
-echo "</table>$stringa_pagine<br><div style=\"text-align: center\">
+echo "</table></div>$stringa_pagine<br><div style=\"text-align: center\">
 <form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div style=\"line-height:160%\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
@@ -1187,7 +1188,7 @@ echo "</select> ".mex("il",$pag)."
 <option value=\"".($anno_corrente + 1)."\">".($anno_corrente + 1)."</option>
 </select><br>
 <table><tr><td style=\"height: 3px;\"></td></tr></table>".mex("testo del messaggio",$pag).":
- <input name=\"testo\" size=\"55\" type=\"text\">&nbsp;&nbsp;&nbsp;
+ <input class=\"widetxt\" name=\"testo\" size=\"55\" type=\"text\">&nbsp;&nbsp;&nbsp;
 <button class=\"send\" type=\"submit\"><div>".mex("Spedisci",$pag)."</div></button>
 </div></form>";
 } # fine if ($priv_ins_messaggi == "s")
