@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -37,6 +37,7 @@ $tableanni = $PHPR_TAB_PRE."anni";
 $tablepersonalizza = $PHPR_TAB_PRE."personalizza";
 $tablerelinventario = $PHPR_TAB_PRE."relinventario";
 $tabledescrizioni = $PHPR_TAB_PRE."descrizioni";
+$tablecostiprenota = $PHPR_TAB_PRE."costiprenota".$anno;
 
 
 $id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
@@ -266,7 +267,21 @@ $aggurlfoto = "";
 if (!$num_app_modifica or controlla_num_pos($num_app_modifica) != "SI") $num_app_modifica = 1;
 
 unset($cambia_nome_app);
-for ($num1 = 0 ;$num1 < $num_app_modifica ; $num1++) {
+for ($num1 = 0 ; $num1 < $num_app_modifica ; $num1++) {
+if (${"num_unita_app".$num1} and strcmp(${"nome_unita_app".$num1},"")) {
+$n_nome_app_unita = ${"n_nome_app".$num1};
+$n_numc_app_unita = ${"n_numcasa".$num1};
+$n_nump_app_unita = ${"n_numpiano".$num1};
+if (($num1 + ${"num_unita_app".$num1}) <= $num_app_modifica) $num_fine_app = $num1 + ${"num_unita_app".$num1};
+else $num_fine_app = $num_app_modifica;
+for ($num2 = $num1 ; $num2 < $num_fine_app ; $num2++) {
+if (substr(${"idappartamenti".$num2},0,strlen(${"nome_unita_app".$num1})) == ${"nome_unita_app".$num1}) {
+${"n_nome_app".$num2} = $n_nome_app_unita.substr(${"idappartamenti".$num2},strlen(${"nome_unita_app".$num1}));
+${"n_numcasa".$num2} = $n_numc_app_unita;
+${"n_numpiano".$num2} = $n_nump_app_unita;
+} # fine if (substr(${"idappartamenti".$num1},0,strlen(${"nome_unita_app".$num1})) == ${"nome_unita_app".$num1})
+} # fine for $num2
+} # fine if (${"num_unita_app".$num1} and strcmp(${"nome_unita_app".$num1},""))
 ${"idappartamenti".$num1} = htmlspecialchars(${"idappartamenti".$num1});
 ${"idappartamenti".$num1} = aggslashdb(${"idappartamenti".$num1});
 if (get_magic_quotes_gpc()) {
@@ -289,10 +304,10 @@ ${"n_app_vicini".$num1} = htmlspecialchars(${"n_app_vicini".$num1});
 if (controlla_num(${"n_maxoccupanti".$num1}) != "SI") unset(${"n_maxoccupanti".$num1});
 if (controlla_num(${"n_priorita".$num1}) != "SI") unset(${"n_priorita".$num1});
 ${"n_commento".$num1} = htmlspecialchars(${"n_commento".$num1});
-if (($form_tabella and strcmp(${"idappartamenti".$num1},${"n_nome_app".$num1})) or (!$form_tabella and ${"n_nome_app".$num1})) $cambia_nome_app = "SI";
 ${"d_numcasa".$num1} = htmlspecialchars(${"d_numcasa".$num1});
 ${"d_numpiano".$num1} = htmlspecialchars(${"d_numpiano".$num1});
 ${"d_commento".$num1} = htmlspecialchars(${"d_commento".$num1});
+if (($form_tabella and strcmp(${"idappartamenti".$num1},${"n_nome_app".$num1})) or (!$form_tabella and ${"n_nome_app".$num1})) $cambia_nome_app = "SI";
 } # fine for $num1
 
 $anni_esistenti = esegui_query("select * from $tableanni order by idanni");
@@ -302,27 +317,40 @@ unset($altre_tab_lock);
 $num_tab = 0;
 $num_altre_tab = 0;
 if ($cambia_nome_app and $modificaappartamento == "Continua") {
-$tabelle_lock[$num_tab] = "$tableanni";
+$tabelle_lock[$num_tab] = $tableanni;
+$num_tab++;
 for ($num1 = 0 ;$num1 < $num_anni_esistenti ; $num1++) {
 $anno_esistente = risul_query($anni_esistenti,$num1,'idanni');
 $tableprenota_lock = $PHPR_TAB_PRE."prenota".$anno_esistente;
-$num_tab++;
 $tabelle_lock[$num_tab] = $tableprenota_lock;
-} # fine for $num1
 $num_tab++;
+} # fine for $num1
+for ($num1 = 0 ;$num1 < $num_anni_esistenti ; $num1++) {
+$anno_esistente = risul_query($anni_esistenti,$num1,'idanni');
+$tablecostiprenota_lock = $PHPR_TAB_PRE."costiprenota".$anno_esistente;
+$tabelle_lock[$num_tab] = $tablecostiprenota_lock;
+$num_tab++;
+} # fine for $num1
+for ($num1 = 0 ;$num1 < $num_anni_esistenti ; $num1++) {
+$anno_esistente = risul_query($anni_esistenti,$num1,'idanni');
+$tablentariffe_lock = $PHPR_TAB_PRE."ntariffe".$anno_esistente;
+$tabelle_lock[$num_tab] = $tablentariffe_lock;
+$num_tab++;
+} # fine for $num1
 } # fine if ($cambia_nome_app and $modificaappartamento == "Continua")
 $tabelle_lock[$num_tab] = $tableappartamenti;
+$num_tab++;
 if ($modificaappartamento == "Continua") {
 if ($cambia_nome_app) {
 for ($num1 = 0 ;$num1 < $num_anni_esistenti ; $num1++) {
 $anno_esistente = risul_query($anni_esistenti,$num1,'idanni');
 $tableregole_lock = $PHPR_TAB_PRE."regole".$anno_esistente;
-$num_tab++;
 $tabelle_lock[$num_tab] = $tableregole_lock;
+$num_tab++;
 } # fine for $num1
 } # fine if ($cambia_nome_app)
-$num_tab++;
 $tabelle_lock[$num_tab] = $tabledescrizioni;
+$num_tab++;
 } # fine if ($modificaappartamento == "Continua")
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 unset($d_letto);
@@ -488,32 +516,55 @@ $modificato = "NO";
 
 if (strcmp($n_nome_app,$comp_nome_app)) {
 $modificato = "SI";
-esegui_query("update $tableappartamenti set idappartamenti = '$n_nome_app' where idappartamenti = '$idappartamenti' ");
+esegui_query("update $tableappartamenti set idappartamenti = '".aggslashdb($n_nome_app)."' where idappartamenti = '".aggslashdb($idappartamenti)."' ");
 for ($num2 = 0 ; $num2 < $num_anni_esistenti ; $num2++) {
 $anno_cambia = risul_query($anni_esistenti,$num2,'idanni');
 $tableprenota_cambia = $PHPR_TAB_PRE."prenota".$anno_cambia;
-esegui_query("update $tableprenota_cambia set idappartamenti = '$n_nome_app' where idappartamenti = '$idappartamenti' ");
+esegui_query("update $tableprenota_cambia set idappartamenti = '".aggslashdb($n_nome_app)."' where idappartamenti = '".aggslashdb($idappartamenti)."' ");
 $prenota_c = esegui_query("select * from $tableprenota_cambia where app_assegnabili != '' ");
 $num_prenota_c = numlin_query($prenota_c);
 for ($num3 = 0 ; $num3 < $num_prenota_c ; $num3++) {
 $app_assegnabili = risul_query($prenota_c,$num3,'app_assegnabili');
-$app_assegnabili = explode(",",$app_assegnabili);
-$num_app_assegnabili = count($app_assegnabili);
-for ($num4 = 0 ; $num4 < $num_app_assegnabili ; $num4++) {
-if ($app_assegnabili[$num4] == $idappartamenti) {
-$app_assegnabili[$num4] = $n_nome_app;
-$n_app_assegnabili = $app_assegnabili[0];
-for ($num5 = 1 ; $num5 < $num_app_assegnabili ; $num5++) {
-$n_app_assegnabili .= ",".$app_assegnabili[$num5];
-} # fine for $num5
+$n_app_assegnabili = substr(str_replace(",$idappartamenti,",",$n_nome_app,",",$app_assegnabili,"),1,-1);
+if ($app_assegnabili != $n_app_assegnabili) {
 $idprenota = risul_query($prenota_c,$num3,'idprenota');
-esegui_query("update $tableprenota_cambia set app_assegnabili = '$n_app_assegnabili' where idprenota = '$idprenota' ");
-break;
-} # fine if ($app_assegnabili[$num4] == $idappartamenti)
-} # fine for $num4
+esegui_query("update $tableprenota_cambia set app_assegnabili = '".aggslashdb($n_app_assegnabili)."' where idprenota = '$idprenota' ");
+} # fine if ($app_assegnabili != $n_app_assegnabili)
+} # fine for $num3
+$prenota_c = esegui_query("select * from $tableprenota_cambia where incompatibilita != '' ");
+$num_prenota_c = numlin_query($prenota_c);
+for ($num3 = 0 ; $num3 < $num_prenota_c ; $num3++) {
+$incompatibilita = risul_query($prenota_c,$num3,'incompatibilita');
+$n_incompatibilita = substr(str_replace(",$idappartamenti,",",$n_nome_app,",",$incompatibilita,"),1,-1);
+if ($incompatibilita != $n_incompatibilita) {
+$idprenota = risul_query($prenota_c,$num3,'idprenota');
+esegui_query("update $tableprenota_cambia set incompatibilita = '".aggslashdb($n_incompatibilita)."' where idprenota = '$idprenota' ");
+} # fine if ($incompatibilita != $n_incompatibilita)
+} # fine for $num3
+$tablecostiprenota_cambia = $PHPR_TAB_PRE."costiprenota".$anno_cambia;
+$costiprenota_c = esegui_query("select * from $tablecostiprenota_cambia where varappincompatibili != '' ");
+$num_costiprenota_c = numlin_query($costiprenota_c);
+for ($num3 = 0 ; $num3 < $num_costiprenota_c ; $num3++) {
+$varappincompatibili = risul_query($costiprenota_c,$num3,'varappincompatibili');
+$n_varappincompatibili = substr(str_replace(",$idappartamenti,",",$n_nome_app,",",$varappincompatibili,"),1,-1);
+if ($varappincompatibili != $n_varappincompatibili) {
+$idcostiprenota = risul_query($costiprenota_c,$num3,'idcostiprenota');
+esegui_query("update $tablecostiprenota_cambia set varappincompatibili = '".aggslashdb($n_varappincompatibili)."' where idcostiprenota = '$idcostiprenota' ");
+} # fine if ($varappincompatibili != $n_varappincompatibili)
+} # fine for $num3
+$tablenometariffe_cambia = $PHPR_TAB_PRE."ntariffe".$anno_cambia;
+$ntariffe_c = esegui_query("select * from $tablenometariffe_cambia where appincompatibili_ca != '' ");
+$num_ntariffe_c = numlin_query($ntariffe_c);
+for ($num3 = 0 ; $num3 < $num_ntariffe_c ; $num3++) {
+$appincompatibili_ca = risul_query($ntariffe_c,$num3,'appincompatibili_ca');
+$n_appincompatibili_ca = substr(str_replace(",$idappartamenti,",",$n_nome_app,",",$appincompatibili_ca,"),1,-1);
+if ($appincompatibili_ca != $n_appincompatibili_ca) {
+$idntariffe = risul_query($ntariffe_c,$num3,'idntariffe');
+esegui_query("update $tablenometariffe_cambia set appincompatibili_ca = '".aggslashdb($n_appincompatibili_ca)."' where idntariffe = '$idntariffe' ");
+} # fine if ($appincompatibili_ca != $n_appincompatibili_ca)
 } # fine for $num3
 $tableregole_cambia = $PHPR_TAB_PRE."regole".$anno_cambia;
-esegui_query("update $tableregole_cambia set app_agenzia = '$n_nome_app' where app_agenzia = '$idappartamenti' ");
+esegui_query("update $tableregole_cambia set app_agenzia = '".aggslashdb($n_nome_app)."' where app_agenzia = '".aggslashdb($idappartamenti)."' ");
 $regole2 = esegui_query("select * from $tableregole_cambia where tariffa_per_app != '' ");
 $num_regole2 = numlin_query($regole2);
 for ($num3 = 0 ; $num3 < $num_regole2 ; $num3++) {
@@ -804,9 +855,10 @@ echo "</td><td>";
 if (!$d_letto) echo "".mex("Cambia in",$pag)." <input type=\"text\" name=\"n_maxoccupanti0\" size=\"2\" maxlength=\"2\">";
 echo "</td></tr>
 <tr><td>".mex("Priorità",$pag).": <b>$d_priorita</b></td>
-<td>".mex("Cambia in",$pag)." <input type=\"text\" name=\"n_priorita0\" size=\"5\" maxlength=\"5\"></td></tr>
+<td>".mex("Cambia in",$pag)." <input type=\"text\" name=\"n_priorita0\" size=\"5\" maxlength=\"5\">
+ <small>(".mex("più bassa viene assegnata prima",$pag).")</small></td></tr>
 <tr><td>".mex($fr1."Appartamenti vicini",'unit.php').": </td>
-<td> <input type=\"text\" name=\"n_app_vicini0\" size=\"25\" value=\"$d_app_vicini\"> (".mex($fr1."lista di appartamenti separati da virgole",'unit.php').")</td></tr>
+<td> <input type=\"text\" name=\"n_app_vicini0\" size=\"25\" value=\"$d_app_vicini\"> <small>(".mex($fr1."lista di appartamenti separati da virgole",'unit.php').")</small></td></tr>
 </table>
 ".mex("Commento",$pag).":<br>
 <textarea name=\"n_commento0\" rows=3 cols=60 style=\"white-space: pre; overflow: auto;\">$d_commento</textarea><br>
@@ -884,12 +936,12 @@ else $d_commento = "";
 if ($priv_mod_tariffe != "n") echo "Italiano: <input type=\"text\" name=\"n_commento_ita\" value=\"$d_commento\" size=\"24\"><br>";
 else echo "<div style=\"width: 300px;\">Italiano: \"<em>$d_commento</em>\"</div>";
 reset($lingue_vett);
-while (list($ini_lingua,$nome_lingua) = each($lingue_vett)) {
+foreach ($lingue_vett as $ini_lingua => $nome_lingua) {
 $d_commento = esegui_query("select testo from $tabledescrizioni where nome = '$idappartamenti' and tipo = 'appcommfoto' and lingua = '$ini_lingua' and numero = '$numfoto' ");
 if (numlin_query($d_commento)) $d_commento = risul_query($d_commento,0,'testo');
 else $d_commento = "";
 echo "".ucfirst($nome_lingua).": <input type=\"text\" name=\"n_commento_$ini_lingua\" value=\"$d_commento\" size=\"24\"><br>";
-} # fine while (list($ini_lingua,$nome_lingua) = each($lingue_vett))
+} # fine foreach ($lingue_vett as $ini_lingua => $nome_lingua)
 echo "<button class=\"edtm\" type=\"submit\"><div>".ucfirst(mex("modifica",$pag))."</div></button>
 </div></form><br></td><td style=\"width: 20px;\"></td><td valign=\"middle\">
 <form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
@@ -902,7 +954,7 @@ echo "<button class=\"edtm\" type=\"submit\"><div>".ucfirst(mex("modifica",$pag)
 </div></form></td></tr></table>";
 } # fine for $num1
 
-if (C_RESTRIZIONI_DEMO_ADMIN == "SI") $readonly = " readonly=\"readonly\"";
+if (defined('C_RESTRIZIONI_DEMO_ADMIN') and C_RESTRIZIONI_DEMO_ADMIN == "SI") $readonly = " readonly=\"readonly\"";
 else $readonly = "";
 echo "<br><form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
