@@ -1394,7 +1394,7 @@ $var_arr_pers = $arr_pers_vett[1];
 $num_arr_pers = risul_query($array_pers,$num1,'numero');
 $var_predef[$num_var_predef] = "$arr_pers(".mex2($var_arr_pers).")";
 $num_var_predef++;
-$option_array .= "<option value=\"a$arr_pers\">".mex("ripetizione array",$pag)." $arr_pers</option>";
+$option_array .= "<option value=\"a$arr_pers\">".mex("ripetizione array",$pag)." $arr_pers [r4]...[/r4]</option>";
 } # fine for $num1
 
 for ($num1 = 0 ; $num1 < $num_var_predef ; $num1++) {
@@ -1405,13 +1405,13 @@ $linea_mod .= "</select>
 </td><td style=\"width: 30px;\"></td><td>
 <input class=\"sbutton\" type=\"submit\" name=\"salva_modifiche\" value=\"".mex("Salva le modifiche",$pag)."\">
 </td><td style=\"width: 30px;\"></td><td>".mex("Limiti",$pag)." <select name=\"tipo_rip\">";
-if (!$multilingua) $linea_mod .= "<option value=\"1\">".mex("ripetizione prenotazioni",$pag)."</option>";
-$linea_mod .= "<option value=\"2\">".mex("ripetizione ospiti",$pag)."</option>
-<option value=\"3\">".mex("ripetizione costi aggiuntivi",$pag)."</option>
+if (!$multilingua) $linea_mod .= "<option value=\"1\">".mex("ripetizione prenotazioni",$pag)." [r]...[/r]</option>";
+$linea_mod .= "<option value=\"2\">".mex("ripetizione ospiti",$pag)." [r2]...[/r2]</option>
+<option value=\"3\">".mex("ripetizione costi aggiuntivi",$pag)." [r3]...[/r3]</option>
 $option_array
-<option value=\"5\">".mex("ripetizione pagamenti",$pag)."</option>
-<option value=\"6\">".mex("ripetizione unità",$pag)."</option>
-<option value=\"7\">".mex("parte sotto condizione",$pag)."</option>
+<option value=\"5\">".mex("ripetizione pagamenti",$pag)." [r5]...[/r5]</option>
+<option value=\"6\">".mex("ripetizione unità",$pag)." [r6]...[/r6]</option>
+<option value=\"7\">".mex("parte sotto condizione",$pag)." [c]...[/c]</option>
 </select>
 <input class=\"sbutton\" type=\"submit\" name=\"aggiungi_ripetizione\" value=\"".mex("Aggiungi",$pag)."\">
 </td></tr>";
