@@ -192,7 +192,7 @@ if ($priv_vedi_beni_inv == "p" or $priv_vedi_beni_inv == "g") {
 $condizione_beni_propri = "where ( utente_inserimento = '$id_utente'";
 if ($priv_vedi_beni_inv == "g") {
 reset($utenti_gruppi);
-while (list($idut_gr,$val) = each($utenti_gruppi)) if ($idut_gr != $id_utente) $condizione_beni_propri .= " or utente_inserimento = '$idut_gr'";
+foreach ($utenti_gruppi as $idut_gr => $val) if ($idut_gr != $id_utente) $condizione_beni_propri .= " or utente_inserimento = '$idut_gr'";
 } # fine if ($priv_vedi_beni_inv == "g")
 $condizione_beni_propri .= " )";
 } # fine if ($priv_vedi_beni_inv == "p" or $priv_vedi_beni_inv == "g")
@@ -201,7 +201,7 @@ if ($priv_vedi_inv_mag == "p" or $priv_vedi_inv_mag == "g") {
 $condizione_mag_propri = "where ( utente_inserimento = '$id_utente'";
 if ($priv_vedi_inv_mag == "g") {
 reset($utenti_gruppi);
-while (list($idut_gr,$val) = each($utenti_gruppi)) if ($idut_gr != $id_utente) $condizione_mag_propri .= " or utente_inserimento = '$idut_gr'";
+foreach ($utenti_gruppi as $idut_gr => $val) if ($idut_gr != $id_utente) $condizione_mag_propri .= " or utente_inserimento = '$idut_gr'";
 } # fine if ($priv_vedi_inv_mag == "g")
 $condizione_mag_propri .= " )";
 } # fine if ($priv_vedi_inv_mag == "p" or $priv_vedi_inv_mag == "g")
@@ -854,17 +854,21 @@ else elem_valminmax2.innerHTML = ' ".mex("e",$pag)." <input type=\"text\" name=\
 </script>
 ";
 $default_tipo_associa = "p";
-$default_minmax = substr($dati_ca[$num_costo]['tariffa1'],0,1);
-$default_valminmax = substr($dati_ca[$num_costo]['tariffa1'],1);
+$minmax_trovato = 0;
+for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) {
+if ($dati_ca[$num_costo]["tipo_associa_tariffa$numtariffa"]) $default_tipo_associa = $dati_ca[$num_costo]["tipo_associa_tariffa".$numtariffa];
+$minmax = substr($dati_ca[$num_costo]["tariffa$numtariffa"],0,1);
+if (!$default_minmax and $minmax and !$minmax_trovato) {
+$default_minmax = $minmax;
+$default_valminmax = substr($dati_ca[$num_costo]["tariffa$numtariffa"],1);
 if ($default_minmax == "|") {
 $default_valminmax = explode("<",$default_valminmax);
 $default_valminmax2 = $default_valminmax[1];
 $default_valminmax = $default_valminmax[0];
 } # fine if ($default_minmax == "|") 
 else $default_valminmax2 = "";
-for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) {
-if ($dati_ca[$num_costo]["tipo_associa_tariffa".$numtariffa]) $default_tipo_associa = $dati_ca[$num_costo]["tipo_associa_tariffa".$numtariffa];
-$minmax = substr($dati_ca[$num_costo]["tariffa".$numtariffa],0,1);
+$minmax_trovato = 1;
+} # fine if (!$default_minmax and $minmax and !$minmax_trovato)
 if ($minmax and $default_minmax != $minmax) $default_minmax = "";
 if ($default_minmax) {
 $valminmax = substr($dati_ca[$num_costo]["tariffa".$numtariffa],1);
@@ -1307,28 +1311,38 @@ echo "<tr><td style=\"height: 1px;\"></td></tr><tr><td valign=\"top\">
 <small>13. </small>".mex("Periodi in cui è permesso<br> inserire il costo",$pag).":</td><td>
 <table id=\"tab_per_perm\"><tr><td>";
 $periodi_permessi = $dati_ca[$num_costo]['periodipermessi'];
-if (!$periodi_permessi) { $checked = " checked"; $b = "<b>"; $b_slash = "</b>"; }
-else { $checked = ""; $b = ""; $b_slash = ""; }
+if (!$periodi_permessi) {
+$num_periodi_permessi = 0;
+$checked = " checked";
+$b = "<b>";
+$b_slash = "</b>";
+} # fine if (!$periodi_permessi)
+else {
+$num_periodi_permessi = count($dati_ca[$num_costo]['sett_periodipermessi_ini']);
+$checked = "";
+$b = "";
+$b_slash = "";
+} # fine else if (!$periodi_permessi)
 echo "<label><input type=\"radio\" name=\"periodi_permessi\" value=\"tutti\"$checked> $b".mex("In tutti",$pag)."$b_slash</label></td></tr>
 <tr><td style=\"white-space: nowrap;\">";
 if ($periodi_permessi) { $checked = " checked"; $b = "<b>"; $b_slash = "</b>"; }
 else { $checked = ""; $b = ""; $b_slash = ""; }
 echo "<label><input type=\"radio\" id=\"pp_s\" name=\"periodi_permessi\" value=\"sel\"$checked> $b".mex("Solo nei periodi selezionati",$pag)."$b_slash:</label></td>
 <td onclick=\"document.getElementById('pp_s').checked='1'\">";
-if (!$num_periodi_permessi_sel) $num_periodi_permessi_sel = count($dati_ca[$num_costo]['sett_periodipermessi_ini']);
+if (!$num_periodi_permessi_sel) $num_periodi_permessi_sel = $num_periodi_permessi;
 if (!$num_periodi_permessi_sel) $num_periodi_permessi_sel = 1;
 if ($aggiungi_periodo_permesso) $num_periodi_permessi_sel++;
 if ($elimina_periodo_permesso) $num_periodi_permessi_sel--;
 for ($num1 = 1 ; $num1 <= $num_periodi_permessi_sel ; $num1++) {
 if ($num1 > 1) echo "<tr><td></td><td>";
-if (!${"pp_dal".$num1} and $num1 <= count($dati_ca[$num_costo]['sett_periodipermessi_ini'])) {
+if (!${"pp_dal".$num1} and $num1 <= $num_periodi_permessi) {
 ${"pp_dal".$num1} = esegui_query("select datainizio from $tableperiodi where idperiodi = '".$dati_ca[$num_costo]['sett_periodipermessi_ini'][($num1 - 1)]."'");
 if (numlin_query(${"pp_dal".$num1}) == 1) ${"pp_dal".$num1} = risul_query(${"pp_dal".$num1},0,'datainizio');
 } # fine if (!${"pp_dal".$num1} and...
 echo mex("dal",$pag)." ";
 $pp_dal = ${"pp_dal".$num1};
 mostra_menu_date(C_DATI_PATH."/selectperiodi$anno.1.php","pp_dal$num1",$pp_dal,"","",$id_utente,$tema);
-if (!${"pp_al".$num1} and $num1 <= count($dati_ca[$num_costo]['sett_periodipermessi_ini'])) {
+if (!${"pp_al".$num1} and $num1 <= $num_periodi_permessi) {
 ${"pp_al".$num1} = esegui_query("select datafine from $tableperiodi where idperiodi = '".$dati_ca[$num_costo]['sett_periodipermessi_fine'][($num1 - 1)]."'");
 if (numlin_query(${"pp_al".$num1}) == 1) ${"pp_al".$num1} = risul_query(${"pp_al".$num1},0,'datafine');
 } # fine if (!${"pp_al".$num1} and...
