@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -729,6 +729,7 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
 </div></form>";
 } # fine if ($mese != $mese_fine_periodi)
 else {
+if ($id_utente == 1) {
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"visualizza_tabelle.php#agg_per\"><div style=\"white-space: nowrap;\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
@@ -737,6 +738,8 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"visualizza_tabelle
 &nbsp;&nbsp;&nbsp;&nbsp;
 <input class=\"sbutton\" type=\"submit\" value=\"".mex("Aggiungi periodi",'visualizza_tabelle.php')."\">
 </div></form>";
+} # fine if ($id_utente == 1)
+else echo "&nbsp;";
 } # fine else if ($mese != $mese_fine_periodi)
 echo "</td></tr></table>";
 
@@ -800,7 +803,7 @@ if ($priv_vedi_tab_mesi == "p") {
 $query_prenota_app_canc .= " and ($tableprenota.utente_inserimento = '$id_utente'";
 if ($priv_prenota_gruppi == "SI") {
 reset($utenti_gruppi);
-while (list($idut_gr,$val) = each($utenti_gruppi)) if ($idut_gr != $id_utente) $query_prenota_app_canc .= " or $tableprenota.utente_inserimento = '$idut_gr'";
+foreach ($utenti_gruppi as $idut_gr => $val) if ($idut_gr != $id_utente) $query_prenota_app_canc .= " or $tableprenota.utente_inserimento = '$idut_gr'";
 } # fine if ($priv_prenota_gruppi == "SI")
 $query_prenota_app_canc .= ")";
 } # fine if ($priv_vedi_tab_mesi == "p")
@@ -872,6 +875,7 @@ var curr_sel_row = 0;
 -->
 </script>
 
+<div class=\"tab_cont\">
 <div style=\"position: relative;\" ondragstart=\"drg(event)\">
 <table class=\"m1ext\" cellspacing=0 cellpadding=0><tr><td>
 <table class=\"m1\" style=\"background-color: $t1color;\" cellpadding=\"$cellpadding\" ><tbody>";
@@ -1057,6 +1061,8 @@ $num2 = $num2 + $colonne - 1;
 } # fine if ($priv_vedi_tab_mesi == "p" and ($utente_inserimento != $id_utente or...
 else {
 
+$link_modifica = "SI";
+$tit_prx = "";
 if ($esiste == 1) {
 $id_prenota = risul_query($prenotazione_presente,$prenota_corr,'idprenota',$tableprenota);
 $lista_prenota_contr .= ",".$id_prenota;
@@ -1072,7 +1078,13 @@ if ($vedi_clienti == "GRUPPI" and !$utenti_gruppi[$utente_inserimento_cli]) $mos
 if ($mostra_cliente == "NO") $cognome = $id_prenota;
 else $cognome = risul_query($prenotazione_presente,$prenota_corr,'cognome',$tableclienti);
 } # fine if ($id_clienti)
-else $cognome = "?";
+else {
+$cognome = "?";
+$link_modifica = "NO";
+$tit_prx = mex("Prenotazione temporanea per bloccare l'appartamento",'unit.php')." ".mex("durante l'inserimento dei dati del cliente quando si inserisce una nuova prenotazione",$pag).".\n
+".mex("Utilizzando il tasto 'cancella' dalla pagina di inserimento dei dati del cliente anche questa prenotazione verrà cancellata",$pag).".\n
+".mex("L'utente amministratore può disabilitare o cambiare la durata di queste prenotazioni da 'configura e personalizza'",$pag).".";
+} # fine if ($id_clienti)
 
 $colore = colore_prenotazione($prenotazione_presente,$prenota_corr);
 
@@ -1092,7 +1104,6 @@ else { $id_fine = $id_data_fine_tab; }
 $colonne = $id_fine - $id_inizio + 1;
 if ($id_utente == 1 and $ini_prenota_succ <= $id_fine_prenota) $cognome = mex("ERRORE",$pag);
 
-$link_modifica = "SI";
 if ($priv_mod_prenotazioni == "n") $link_modifica = "NO";
 if ($priv_mod_prenotazioni == "p" and $utente_inserimento != $id_utente) $link_modifica = "NO";
 if ($priv_mod_prenotazioni == "g" and !$utenti_gruppi[$utente_inserimento]) $link_modifica = "NO";
@@ -1120,8 +1131,11 @@ else $array_app_ass_js .= "ApAs[$id_prenota] = '$assegnazioneapp';
 ";
 $array_data_ins_js .= "DaIn[$id_prenota] = '".risul_query($prenotazione_presente,$prenota_corr,'datainserimento',$tableprenota)."';
 ";
-} # fine ($link_modifica == "SI")
-else $id_prn = " id=\"prx$id_prenota\"";
+} # fine if ($link_modifica == "SI")
+else {
+$id_prn = " id=\"prx$id_prenota\"";
+if ($tit_prx) $id_prn .= " title=\"$tit_prx\"";
+} # fine else if ($link_modifica == "SI")
 
 $riduci_font = "";
 $lung_cognome = num_caratteri_testo($cognome);
@@ -1175,7 +1189,7 @@ else $num_ripeti++;
 
 unlock_tabelle($tabelle_lock);
 
-echo "</tbody></table></td></tr></table></div>
+echo "</tbody></table></td></tr></table></div></div>
 <form id=\"mod_pren\" accept-charset=\"utf-8\" method=\"post\" action=\"modifica_prenota.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
@@ -1303,6 +1317,8 @@ echo "</td></tr><tr><td style=\"height: 2px;\"></td></tr><tr><td></td><td align=
 echo "</td></tr><tr><td style=\"height: 12px;\"></td></tr></table>";
 
 if ($show_bar != "NO") {
+if (!$mobile_device) echo "<div style=\"text-align: center; font-size: 80%; padding-bottom: 6px;\">".mex("Premere su una prenotazione e trascinarla per spostarla in un nuovo appartamento",'unit.php').".
+ ".mex("Trascinare l'inizio o la fine di una prenotazione per cambiare la data di arrivo o partenza",$pag).".</div>";
 echo "<table style=\"margin-left: auto; margin-right: auto;\" cellspacing=\"0\" cellpadding=\"1\"><tr>
 <td>&nbsp;</td><td style=\"background-color: $colore_rosso; width: 60px; border: solid black 1px; border-radius: 10px;\">&nbsp;</td><td>&nbsp;</td>
 <td style=\"width: 50px;\"></td>
