@@ -342,7 +342,7 @@ if ($mostra_contratto == "SI") {
 
 
 
-define(C_ID_UTENTE,$id_utente);
+define('C_ID_UTENTE',$id_utente);
 $campi_pers_comm = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'campi_pers_comm' and idutente = '$id_utente'");
 if (numlin_query($campi_pers_comm) == 1) {
 $campi_pers_comm = explode(">",risul_query($campi_pers_comm,0,'valpersonalizza'));
@@ -374,7 +374,7 @@ if ($priv_vedi_tab_prenotazioni != "n" or ($priv_vedi_tab_mesi != "n" and $priv_
 $lista_prenota = explode(",",$lista_prenota);
 $num_ripeti = count($lista_prenota) - 2;
 include("./includes/dati_lista_prenota.php");
-} # fine if ($priv_vedi_tab_mesi == "s" or ($priv_vedi_tab_mesi == "s" and $priv_mod_prenotazioni != "n"))
+} # fine if ($priv_vedi_tab_mesi != "n" or ($priv_vedi_tab_mesi != "n" and $priv_mod_prenotazioni != "n"))
 } # fine if ($lista_prenota)
 
 if ($lista_clienti) {
